@@ -33,7 +33,7 @@ ATC_NICOTINE = u'N07BA01'
 ATC_ETHANOL  = u'V03AB16'
 
 #============================================================
-def propagate_atc(substance=None, atc=None):
+def propagate_atc(substance=None, atc=None, link_obj=None):
 
 	_log.debug('substance <%s>, ATC <%s>', substance, atc)
 
@@ -42,7 +42,7 @@ def propagate_atc(substance=None, atc=None):
 			atc = None
 
 	if atc is None:
-		atcs = text2atc(text = substance, fuzzy = False)
+		atcs = text2atc(text = substance, fuzzy = False, link_obj = link_obj)
 		if len(atcs) == 0:
 			_log.debug(u'no ATC found, aborting')
 			return atc
@@ -53,17 +53,17 @@ def propagate_atc(substance=None, atc=None):
 
 	args = {'atc': atc, 'term': substance.strip()}
 	queries = [
-		{'cmd': u"UPDATE ref.consumable_substance SET atc_code = %(atc)s WHERE lower(description) = lower(%(term)s) AND atc_code IS NULL",
+		{'cmd': u"UPDATE ref.substance SET atc = %(atc)s WHERE lower(description) = lower(%(term)s) AND atc IS NULL",
 		 'args': args},
-		{'cmd': u"UPDATE ref.branded_drug SET atc_code = %(atc)s WHERE lower(description) = lower(%(term)s) AND atc_code IS NULL",
+		{'cmd': u"UPDATE ref.drug_product SET atc_code = %(atc)s WHERE lower(description) = lower(%(term)s) AND atc_code IS NULL",
 		 'args': args}
 	]
-	gmPG2.run_rw_queries(queries = queries)
+	gmPG2.run_rw_queries(link_obj = link_obj, queries = queries)
 
 	return atc
 
 #============================================================
-def text2atc(text=None, fuzzy=False):
+def text2atc(text=None, fuzzy=False, link_obj=None):
 
 	text = text.strip()
 
@@ -76,12 +76,12 @@ def text2atc(text=None, fuzzy=False):
 				FROM ref.v_atc
 				WHERE term ilike %(term)s AND atc IS NOT NULL
 					UNION
-				SELECT atc_code, null, null
-				FROM ref.consumable_substance
-				WHERE description ilike %(term)s AND atc_code IS NOT NULL
+				SELECT atc as atc_code, null, null
+				FROM ref.substance
+				WHERE description ilike %(term)s AND atc IS NOT NULL
 					UNION
 				SELECT atc_code, null, null
-				FROM ref.branded_drug
+				FROM ref.drug_product
 				WHERE description ilike %(term)s AND atc_code IS NOT NULL
 			) as tmp
 			ORDER BY atc_code
@@ -95,23 +95,30 @@ def text2atc(text=None, fuzzy=False):
 				FROM ref.v_atc
 				WHERE lower(term) = lower(%(term)s) AND atc IS NOT NULL
 					UNION
-				SELECT atc_code, null, null
-				FROM ref.consumable_substance
-				WHERE lower(description) = lower(%(term)s) AND atc_code IS NOT NULL
+				SELECT atc as atc_code, null, null
+				FROM ref.substance
+				WHERE lower(description) = lower(%(term)s) AND atc IS NOT NULL
 					UNION
 				SELECT atc_code, null, null
-				FROM ref.branded_drug
+				FROM ref.drug_product
 				WHERE lower(description) = lower(%(term)s) AND atc_code IS NOT NULL
 			) as tmp
 			ORDER BY atc_code
 		"""
 
-	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}], get_col_idx = False)
+	rows, idx = gmPG2.run_ro_queries(link_obj = link_obj, queries = [{'cmd': cmd, 'args': args}], get_col_idx = False)
 
 	_log.debug(u'term: %s => ATCs: %s (fuzzy: %s)', text, rows, fuzzy)
 
 	return rows
 
+#============================================================
+def exists_as_atc(substance):
+	args = {'term': substance}
+	cmd = u'SELECT EXISTS (SELECT 1 FROM ref.atc WHERE lower(term) = lower(%(term)s))'
+	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}], get_col_idx = False)
+	return rows[0][0]
+
 #============================================================
 def get_reference_atcs(order_by=u'atc, term, lang'):
 	cmd = u'SELECT * FROM ref.v_atc ORDER BY %s' % order_by
