@@ -21,6 +21,8 @@ import httplib2
 import json
 import zipfile
 import shutil
+import time
+import datetime as pydt
 from urllib import urlencode
 import distutils.version as version
 
@@ -59,7 +61,11 @@ class cOrthancServer:
 	def connect(self, host, port, user, password, expected_minimal_version=None, expected_name=None, expected_aet=None):
 		if (host is None) or (host.strip() == u''):
 			host = u'localhost'
-		self.__server_url = str('http://%s:%s' % (host, port))
+		try:
+			self.__server_url = str('http://%s:%s' % (host, port))
+		except Exception:
+			_log.exception(u'cannot create server url from: host [%s] and port [%s]', host, port)
+			return False
 		self.__user = user
 		self.__password = password
 		_log.info('connecting as [%s] to Orthanc server at [%s]', self.__user, self.__server_url)
@@ -99,6 +105,30 @@ class cOrthancServer:
 			return False
 		_log.debug('server: %s', system_data)
 		self.__server_identification = system_data
+
+		# check time skew
+		tolerance = 60 # seconds
+		client_now_as_utc = pydt.datetime.utcnow()
+		start = time.time()
+		orthanc_now_str = self.__run_GET(url = '%s/tools/now' % self.__server_url)		# 20180208T165832
+		end = time.time()
+		query_duration = end - start
+		orthanc_now_unknown_tz = pydt.datetime.strptime(orthanc_now_str, '%Y%m%dT%H%M%S')
+		_log.info('GNUmed "now" (UTC): %s', client_now_as_utc)
+		_log.info('Orthanc "now" (UTC): %s', orthanc_now_unknown_tz)
+		_log.debug('wire roundtrip (seconds): %s', query_duration)
+		_log.debug('maximum skew tolerance (seconds): %s', tolerance)
+		if query_duration > tolerance:
+			_log.error('useless to check GNUmed/Orthanc time skew, wire roundtrip > tolerance (%s)', tolerance)
+		else:
+			if orthanc_now_unknown_tz > client_now_as_utc:
+				real_skew = orthanc_now_unknown_tz - client_now_as_utc
+			else:
+				real_skew = client_now_as_utc - orthanc_now_unknown_tz
+			_log.debug('GNUmed/Orthanc time skew: %s', real_skew)
+			if real_skew > pydt.timedelta(seconds = tolerance):
+				_log.error('GNUmed/Orthanc time skew > tolerance (may be due to timezone differences)')
+
 		return self.__server_identification
 
 	server_identification = property(_get_server_identification, lambda x:x)
@@ -428,20 +458,34 @@ class cOrthancServer:
 		_log.info(u'exporting %s studies into [%s]', len(study_ids), filename)
 		_log.debug(u'studies: %s', study_ids)
 		f = io.open(filename, 'wb')
-		url = '%s/tools/create-media' % self.__server_url
-		_log.debug(url)
 		#  You have to make a POST request against URI "/tools/create-media", with a
 		#  JSON body that contains the array of the resources of interest (as Orthanc
 		#  identifiers). Here is a sample command-line:
 		#  curl -X POST http://localhost:8042/tools/create-media -d '["8c4663df-c3e66066-9e20a8fc-dd14d1e5-251d3d84","2cd4848d-02f0005f-812ffef6-a210bbcf-3f01a00a","6eeded74-75005003-c3ae9738-d4a06a4f-6beedeb8","8a622020-c058291c-7693b63f-bc67aa2e-0a02e69c"]' -v > /tmp/a.zip
 		#  (this will not create duplicates but will also not check for single-patient-ness)
+		url = '%s/tools/create-media-extended' % self.__server_url
+		_log.debug(url)
 		try:
-			f.write(self.__run_POST(url = url, data = study_ids))
+			downloaded = self.__run_POST(url = url, data = study_ids, output_file = f)
+			if not downloaded:
+				_log.error('this Orthanc version probably does not support "create-media-extended"')
 		except TypeError:
 			f.close()
 			_log.exception('cannot retrieve multiple studies as one archive with DICOMDIR, probably not supported by this Orthanc version')
 			return False
-		f.close()
+		# retry with old URL
+		if not downloaded:
+			url = '%s/tools/create-media' % self.__server_url
+			_log.debug(u'retrying: %s', url)
+			try:
+				downloaded = self.__run_POST(url = url, data = study_ids, output_file = f)
+				if not downloaded:
+					return False
+			except TypeError:
+				_log.exception('cannot retrieve multiple studies as one archive with DICOMDIR, probably not supported by this Orthanc version')
+				return False
+			finally:
+				f.close()
 		if create_zip:
 			return filename
 		if target_dir is None:
@@ -451,6 +495,39 @@ class cOrthancServer:
 			return False
 		return target_dir
 
+	#--------------------------------------------------------
+	def get_instance_dicom_tags(self, instance_id, simplified=True):
+		_log.debug('retrieving DICOM tags for instance [%s]', instance_id)
+		if simplified:
+			download_url = '%s/instances/%s/simplified-tags' % (self.__server_url, instance_id)
+		else:
+			download_url = '%s/instances/%s/tags' % (self.__server_url, instance_id)
+		return self.__run_GET(url = download_url)
+
+	#--------------------------------------------------------
+	def get_instance_preview(self, instance_id, filename=None):
+		if filename is None:
+			filename = gmTools.get_unique_filename(suffix = '.png')
+
+		_log.debug('exporting preview for instance [%s] into [%s]', instance_id, filename)
+		download_url = '%s/instances/%s/preview' % (self.__server_url, instance_id)
+		f = io.open(filename, 'wb')
+		f.write(self.__run_GET(url = download_url))
+		f.close()
+		return filename
+
+	#--------------------------------------------------------
+	def get_instance(self, instance_id, filename=None):
+		if filename is None:
+			filename = gmTools.get_unique_filename(suffix = '.dcm')
+
+		_log.debug('exporting instance [%s] into [%s]', instance_id, filename)
+		download_url = '%s/instances/%s/attachments/dicom/data' % (self.__server_url, instance_id)
+		f = io.open(filename, 'wb')
+		f.write(self.__run_GET(url = download_url))
+		f.close()
+		return filename
+
 	#--------------------------------------------------------
 	# server-side API
 	#--------------------------------------------------------
@@ -483,6 +560,28 @@ class cOrthancServer:
 		url = '%s/patients/%s/protected' % (self.__server_url, str(orthanc_id))
 		return (self.__run_GET(url) == 1)
 
+	#--------------------------------------------------------
+	def verify_patient_data(self, orthanc_id):
+		_log.info('verifying DICOM data of patient [%s]', orthanc_id)
+		bad_data = []
+		instances_url = '%s/patients/%s/instances' % (self.__server_url, orthanc_id)
+		instances = self.__run_GET(instances_url)
+		for instance in instances:
+			instance_id = instance['ID']
+			attachments_url = '%s/instances/%s/attachments' % (self.__server_url, instance_id)
+			attachments = self.__run_GET(attachments_url)
+			for attachment in attachments:
+				verify_url = '%s/%s/verify-md5' % (attachments_url, attachment)
+				# False, success = "{}"
+				#2018-02-08 19:11:27  ERROR     gm.dicom      [-1211701504 MainThread]  (gmDICOM.py::__run_POST() #986): cannot POST: http://localhost:8042/instances/5a8206f4-24619e76-6650d9cd-792cdf25-039e96e6/attachments/dicom-as-json/verify-md5
+				#2018-02-08 19:11:27  ERROR     gm.dicom      [-1211701504 MainThread]  (gmDICOM.py::__run_POST() #987): response: {'status': '400', 'content-length': '0'}
+				if self.__run_POST(verify_url) is not False:
+					continue
+				_log.error(u'bad MD5 of DICOM file at url [%s]: patient=%s, attachment_type=%s', verify_url, orthanc_id, attachment)
+				bad_data.append({'patient': orthanc_id, 'instance': instance_id, 'type': attachment, 'orthanc': u'%s [%s]' % (self.server_identification, self.__server_url)})
+
+		return bad_data
+
 	#--------------------------------------------------------
 	def modify_patient_id(self, old_patient_id, new_patient_id):
 
@@ -668,11 +767,7 @@ class cOrthancServer:
 			except KeyError:
 				pass
 			for key in pat_dict:
-				if pat_dict[key] == u'unknown':
-					pat_dict[key] = None
-				if pat_dict[key] == u'(null)':
-					pat_dict[key] = None
-				if pat_dict[key] == u'':
+				if pat_dict[key] in [u'unknown', u'(null)', u'']:
 					pat_dict[key] = None
 				pat_dict[key] = cleanup_dicom_string(pat_dict[key])
 			studies_by_patient.append(pat_dict)
@@ -718,11 +813,7 @@ class cOrthancServer:
 				except KeyError:
 					pass
 				for key in study_dict:
-					if study_dict[key] == u'unknown':
-						study_dict[key] = None
-					if study_dict[key] == u'(null)':
-						study_dict[key] = None
-					if study_dict[key] == u'':
+					if study_dict[key] in [u'unknown', u'(null)', u'']:
 						study_dict[key] = None
 					study_dict[key] = cleanup_dicom_string(study_dict[key])
 				study_dict['all_tags'] = {}
@@ -749,18 +840,22 @@ class cOrthancServer:
 				# loop over series in study
 				for orth_series_id in orth_study['Series']:
 					orth_series = self.__run_GET(url = u'%s/series/%s' % (self.__server_url, orth_series_id))
+					#slices = orth_series['Instances']
+					ordered_slices = self.__run_GET(url = u'%s/series/%s/ordered-slices' % (self.__server_url, orth_series_id))
+					slices = [ s[0] for s in ordered_slices['SlicesShort'] ]
 					if orth_series is False:
 						_log.error('cannot retrieve series')
 						return []
 					series_dict = {
 						'orthanc_id': orth_series['ID'],
-						'instances': len(orth_series['Instances']),
+						'instances': slices,
 						'modality': None,
 						'date': None,
 						'time': None,
 						'description': None,
 						'body_part': None,
-						'protocol': None
+						'protocol': None,
+						'performed_procedure_step_description': None
 					}
 					try:
 						series_dict['modality'] = orth_series['MainDicomTags']['Modality'].strip()
@@ -786,16 +881,21 @@ class cOrthancServer:
 						series_dict['protocol'] = orth_series['MainDicomTags']['ProtocolName'].strip()
 					except KeyError:
 						pass
+					try:
+						series_dict['performed_procedure_step_description'] = orth_series['MainDicomTags']['PerformedProcedureStepDescription'].strip()
+					except KeyError:
+						pass
 					for key in series_dict:
-						if series_dict[key] == u'unknown':
-							series_dict[key] = None
-						if series_dict[key] == u'(null)':
-							series_dict[key] = None
-						if series_dict[key] == u'':
+						if series_dict[key] in [u'unknown', u'(null)', u'']:
 							series_dict[key] = None
 					if series_dict['description'] == series_dict['protocol']:
 						_log.debug('<series description> matches <series protocol>, ignoring protocol')
 						series_dict['protocol'] = None
+					if series_dict['performed_procedure_step_description'] in [series_dict['description'], series_dict['protocol']]:
+						series_dict['performed_procedure_step_description'] = None
+					if series_dict['performed_procedure_step_description'] is not None:
+						if regex.match ('[.,/\|\-\s\d]+', series_dict['performed_procedure_step_description'], flags = regex.UNICODE):
+							series_dict['performed_procedure_step_description'] = None
 					if series_dict['date'] == study_dict['date']:
 						_log.debug('<series date> matches <study date>, ignoring date')
 						series_dict['date'] = None
@@ -857,8 +957,8 @@ class cOrthancServer:
 			return content
 
 	#--------------------------------------------------------
-	def __run_POST(self, url=None, data=None, content_type=u''):
-		if isinstance(data, str):
+	def __run_POST(self, url=None, data=None, content_type=u'', output_file=None):
+		if isinstance(data, basestring):
 			body = data
 			if len(content_type) != 0:
 				headers = { 'content-type' : content_type }
@@ -888,19 +988,28 @@ class cOrthancServer:
 
 		if response.status == 404:
 			_log.debug(u'no data, response: %s', response)
-			return []
+			if output_file is None:
+				return []
+			return False
 		if not (response.status in [ 200, 302 ]):
 			_log.error(u'cannot POST: %s', url)
 			_log.error(u'response: %s', response)
 			return False
+		#_log.debug(u'response: %s', response)
 		try:
-			return json.loads(content)
+			content = json.loads(content)
+#			return json.loads(content)
 		except StandardError:
+			pass
+#			return content
+		if output_file is None:
 			return content
+		output_file.write(content)
+		return True
 
 	#--------------------------------------------------------
 	def __run_PUT(self, url=None, data=None, content_type=u''):
-		if isinstance(data, str):
+		if isinstance(data, basestring):
 			body = data
 			if len(content_type) != 0:
 				headers = { 'content-type' : content_type }
@@ -1007,23 +1116,28 @@ if __name__ == "__main__":
 			pats = orthanc.get_patients_by_name(name_parts = entered_name.split(), fuzzy = True)
 			for pat in pats:
 				print(pat)
+				bad_data = orthanc.verify_patient_data(pat['ID'])
+				for bad in bad_data:
+					print(bad)
 				continue
 
+			continue
+
 			pats = orthanc.get_studies_list_by_patient_name(name_parts = entered_name.split(), fuzzy = True)
 			for pat in pats:
 				print(pat['name'])
 				for study in pat['studies']:
 					print(u' ', gmTools.format_dict_like(study, relevant_keys = ['orthanc_id', 'date', 'time'], template = u'study [%%(orthanc_id)s] at %%(date)s %%(time)s contains %s series' % len(study['series'])))
-					for series in study['series']:
-						print (
-							u'  ',
-							gmTools.format_dict_like (
-								series,
-								relevant_keys = ['orthanc_id', 'date', 'time', 'modality', 'instances', 'body_part', 'protocol', 'description', 'station'],
-								template = u'series [%(orthanc_id)s] at %(date)s %(time)s: "%(description)s" %(modality)s@%(station)s (%(protocol)s) of body part "%(body_part)s" holds %(instances)s images'
-							)
-						)
-				#print(orthanc.get_study_as_zip_with_dicomdir(study_id = study['orthanc_id'], filename = 'study_%s.zip' % study['orthanc_id']))
+#					for series in study['series']:
+#						print (
+#							u'  ',
+#							gmTools.format_dict_like (
+#								series,
+#								relevant_keys = ['orthanc_id', 'date', 'time', 'modality', 'instances', 'body_part', 'protocol', 'description', 'station'],
+#								template = u'series [%(orthanc_id)s] at %(date)s %(time)s: "%(description)s" %(modality)s@%(station)s (%(protocol)s) of body part "%(body_part)s" holds images:\n%(instances)s'
+#							)
+#						)
+					print(orthanc.get_studies_with_dicomdir(study_ids = [study['orthanc_id']], filename = 'study_%s.zip' % study['orthanc_id'], create_zip = True))
 				#print(orthanc.get_study_as_zip(study_id = study['orthanc_id'], filename = 'study_%s.zip' % study['orthanc_id']))
 				#print(orthanc.get_studies_as_zip_with_dicomdir(study_ids = [ s['orthanc_id'] for s in pat['studies'] ], filename = 'studies_of_%s.zip' % pat['orthanc_id']))
 				print(u'--------')
@@ -1032,11 +1146,15 @@ if __name__ == "__main__":
 	def run_console():
 		try:
 			host = sys.argv[2]
-			port = sys.argv[3]
 		except IndexError:
 			host = None
+		try:
+			port = sys.argv[3]
+		except IndexError:
 			port = '8042'
+
 		orthanc_console(host, port)
+
 	#--------------------------------------------------------
 	def test_modify_patient_id():
 		try:
@@ -1100,6 +1218,27 @@ if __name__ == "__main__":
 		orthanc.upload_from_directory(directory = sys.argv[2], recursive = True, check_mime_type = False, ignore_other_files = True)
 
 	#--------------------------------------------------------
-	#run_console()
+	def test_get_instance_preview():
+		host = None
+		port = '8042'
+
+		orthanc = cOrthancServer()
+		if not orthanc.connect(host, port, user = None, password = None):		#, expected_aet = 'another AET'
+			print('error connecting to server:', orthanc.connect_error)
+			return False
+		print('Connected to Orthanc server "%s" (AET [%s] - version [%s] - DB [%s])' % (
+			orthanc.server_identification['Name'],
+			orthanc.server_identification['DicomAet'],
+			orthanc.server_identification['Version'],
+			orthanc.server_identification['DatabaseVersion']
+		))
+		print('')
+
+		print(orthanc.get_instance_preview('f4f07d22-0d8265ef-112ea4e9-dc140e13-350c06d1'))
+		print(orthanc.get_instance('f4f07d22-0d8265ef-112ea4e9-dc140e13-350c06d1'))
+
+	#--------------------------------------------------------
+	run_console()
 	#test_modify_patient_id()
-	test_upload_files()
+	#test_upload_files()
+	#test_get_instance_preview()
