@@ -1073,6 +1073,9 @@ class cLaTeXForm(cFormEngine):
 	#--------------------------------------------------------
 	def substitute_placeholders(self, data_source=None):
 
+		# debugging
+		#data_source.debug = True
+
 		if self.template is not None:
 			# inject placeholder values
 			data_source.set_placeholder(u'form_name_long', self.template['name_long'])
@@ -1096,9 +1099,9 @@ class cLaTeXForm(cFormEngine):
 		]
 		regexen = [
 			'dummy',
-			data_source.first_pass_placeholder_regex,
-			data_source.second_pass_placeholder_regex,
-			data_source.third_pass_placeholder_regex
+			r'\$1{0,1}<[^<].+?>1{0,1}\$',
+			r'\$2<[^<].+?>2\$',
+			r'\$3<[^<].+?>3\$'
 		]
 
 		current_pass = 1
@@ -1148,17 +1151,30 @@ class cLaTeXForm(cFormEngine):
 				continue
 
 			# 2) replace them
-			_log.debug('%s placeholders found in this line', len(placeholders_in_line))
+			_log.debug('replacing in non-empty, non-comment line: >>>%s<<<', line.rstrip(u'\n'))
+			_log.debug('%s placeholder(s) detected', len(placeholders_in_line))
 			for placeholder in placeholders_in_line:
+				original_ph_def = placeholder
+				_log.debug('placeholder: >>>%s<<<', original_ph_def)
+				# normalize start/end
+				if placeholder.startswith('$<'):
+					placeholder = '$1<' + placeholder[2:]
+				if placeholder.endswith('>$'):
+					placeholder = placeholder[:-2] + '>1$'
+				_log.debug('normalized : >>>%s<<<', placeholder)
+				# remove start/end
+				placeholder = placeholder[3:-3]
+				_log.debug('stripped   : >>>%s<<<', placeholder)
 				try:
 					val = data_source[placeholder]
 				except:
-					_log.exception('error with placeholder [%s]', placeholder)
-					val = gmTools.tex_escape_string(_('error with placeholder [%s]') % placeholder)
+					_log.exception('error with placeholder [%s]', original_ph_def)
+					val = gmTools.tex_escape_string(_('error with placeholder [%s]') % original_ph_def)
 				if val is None:
-					_log.debug('error with placeholder [%s]', placeholder)
-					val = gmTools.tex_escape_string(_('error with placeholder [%s]') % placeholder)
-				line = line.replace(placeholder, val)
+					_log.debug('error with placeholder [%s]', original_ph_def)
+					val = gmTools.tex_escape_string(_('error with placeholder [%s]') % original_ph_def)
+				_log.debug('value      : >>>%s<<<', val)
+				line = line.replace(original_ph_def, val)
 			instance_file.write(line)
 
 		instance_file.close()
