@@ -1279,62 +1279,3 @@ if __name__ == '__main__':
 				pass
 			clean_test_org()
 			clean_org_categories(adminlogin)
-
-
-
-def setPostcodeWidgetFromUrbId(postcodeWidget, id_urb):
-         """convenience method for urb and postcode phrasewheel interaction.
-            never called without both arguments, but need to check that id_urb
-            is not invalid"""
-         #TODO type checking that the postcodeWidget is a phrasewheel configured
-         # with a postcode matcher
-         if  postcodeWidget is None or id_urb is None:
-                 return False
-         postcode = getPostcodeForUrbId(id_urb)
-         if postcode is None:
-                 return False
-         if len(postcode) == 0:
-                 return True
-         postcodeWidget.SetValue(postcode)
-         postcodeWidget.input_was_selected= 1
-         return True
-
- #------------------------------------------------------------
-
-def setUrbPhraseWheelFromPostcode(pwheel, postcode):
-         """convenience method for common postcode to urb phrasewheel collaboration.
-            there is no default args for these utility functions,
-            This function is never called without both arguments, otherwise
-            there is no intention (= modify the urb phrasewheel with postcode value).
-         """
-         # TODO type checking that the pwheel is a urb phrasewheel with a urb matcher
-         # clearing post code unsets target
-         # phrasewheel's postcode context
-         if pwheel is None:
-                 return False
-         if postcode == '':
-                 pwheel.set_context("postcode", "%")
-                 return True
-         urbs = getUrbsForPostcode(postcode)
-         if urbs is None:
-                 return False
-         if len(urbs) == 0:
-                 return True
-         pwheel.SetValue(urbs[0])
-         pwheel.input_was_selected = 1
-
-         # FIXME: once the postcode context is set,
-         # the urb phrasewheel will only return urbs with
-         # the same postcode. These can be viewed by clearing
-         # the urb widget. ?How to unset the postcode context,
-         # some gui gesture ? clearing the postcode
-         # (To view all the urbs for a set context,
-         # put a "*" in the urb box and activate the picklist.
-         # THE PROBLEM WITH THIS IS IF THE USER CLEARS THE BOX AND SET CONTEXT IS RESET,
-         # then the "*" will try to pull all thousands of urb names, freezing the app.
-         # so needs a fixup (? have SQL select ... LIMIT n in Phrasewheel )
-
-         pwheel.set_context("postcode", postcode)
-         return True
-
-#======================================================================
