@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+
+from __future__ import print_function
+
 """GNUmed patient objects.
 
 This is a patient object intended to let a useful client-side
@@ -14,7 +17,6 @@ import os.path
 import time
 import re as regex
 import datetime as pyDT
-import io
 import thread
 import threading
 import logging
@@ -154,7 +156,7 @@ class cDTO_person(object):
 	def delete_from_source(self):
 		pass
 	#--------------------------------------------------------
-	def is_unique(self):
+	def _is_unique(self):
 		where_snippets = [
 			u'firstnames = %(first)s',
 			u'lastnames = %(last)s'
@@ -174,9 +176,10 @@ class cDTO_person(object):
 
 		return rows[0][0] == 1
 
-	is_unique = property(is_unique, lambda x:x)
+	is_unique = property(_is_unique)
+
 	#--------------------------------------------------------
-	def exists(self):
+	def _exists(self):
 		where_snippets = [
 			u'firstnames = %(first)s',
 			u'lastnames = %(last)s'
@@ -196,7 +199,8 @@ class cDTO_person(object):
 
 		return rows[0][0] > 0
 
-	exists = property(exists, lambda x:x)
+	exists = property(_exists)
+
 	#--------------------------------------------------------
 	def get_candidate_identities(self, can_create=False):
 		"""Generate generic queries.
@@ -1409,6 +1413,60 @@ class cPerson(gmBusinessDBObject.cBusinessDBObject):
 		vcf.close()
 
 		return filename
+
+	#--------------------------------------------------------
+	def export_as_mecard(self, filename=None):
+		if filename is None:
+			filename = gmTools.get_unique_filename (
+				prefix = 'gm-patient-',
+				suffix = '.mcf'
+			)
+		with io.open(filename, mode = 'wt', encoding = 'utf8') as mecard_file:
+			mecard_file.write(self.MECARD)
+		return filename
+
+	#--------------------------------------------------------
+	def _get_mecard(self):
+		"""
+		http://blog.thenetimpact.com/2011/07/decoding-qr-codes-how-to-format-data-for-qr-code-generators/
+		https://www.nttdocomo.co.jp/english/service/developer/make/content/barcode/function/application/addressbook/index.html
+
+		MECARD:N:NAME;ADR:pobox,subunit,unit,street,ort,region,zip,country;TEL:111111111;FAX:22222222;EMAIL:mail@praxis.org;
+
+
+		MECARD:N:lastname,firstname;BDAY:YYYYMMDD;ADR:pobox,subunit,number,street,location,region,zip,country;;
+		MECARD:N:$<lastname::::>$,$<firstname::::>$;BDAY:$<date_of_birth::%Y%m%d::>$;ADR:,$<adr_subunit::home::>$,$<adr_number::home::>$,$<adr_street::home::>$,$<adr_location::home::>$,,$<adr_postcode::home::>$,$<adr_country::home::>$;;
+		"""
+		MECARD = 'MECARD:N:%s,%s;' % (
+			self._payload[self._idx['lastnames']],
+			self._payload[self._idx['firstnames']]
+		)
+		if self._payload[self._idx['dob']] is not None:
+			MECARD += 'BDAY:%s;' % gmDateTime.pydt_strftime (
+				self._payload[self._idx['dob']],
+				'%Y%m%d',
+				accuracy = gmDateTime.acc_days,
+				none_str = ''
+			)
+		adrs = self.get_addresses(address_type = 'home')
+		if len(adrs) > 0:
+			MECARD += 'ADR:,%(subunit)s,%(number)s,%(street)s,%(urb)s,,%(postcode)s,%(l10n_country)s;' % adrs[0]
+		comms = self.get_comm_channels(comm_medium = 'homephone')
+		if len(comms) > 0:
+			if not comms[0]['is_confidential']:
+				MECARD += 'TEL:%s;' % comms[0]['url']
+		comms = self.get_comm_channels(comm_medium = 'fax')
+		if len(comms) > 0:
+			if not comms[0]['is_confidential']:
+				MECARD += 'FAX:%s;' % comms[0]['url']
+		comms = self.get_comm_channels(comm_medium = 'email')
+		if len(comms) > 0:
+			if not comms[0]['is_confidential']:
+				MECARD += 'EMAIL:%s;' % comms[0]['url']
+		return MECARD
+
+	MECARD = property(_get_mecard)
+
 	#--------------------------------------------------------
 	# occupations API
 	#--------------------------------------------------------
@@ -2217,9 +2275,9 @@ class gmCurrentPatient(gmBorg.cBorg):
 				successful = call_back()
 			except:
 				_log.exception('callback [%s] failed', call_back)
-				print "*** pre-change callback failed ***"
-				print type(call_back)
-				print call_back
+				print("*** pre-change callback failed ***")
+				print(type(call_back))
+				print(call_back)
 				return False
 
 			if not successful:
@@ -2568,22 +2626,22 @@ if __name__ == '__main__':
 	def test_set_active_pat():
 
 		ident = cPerson(1)
-		print "setting active patient with", ident
+		print("setting active patient with", ident)
 		set_active_patient(patient=ident)
 
 		patient = cPatient(12)
-		print "setting active patient with", patient
+		print("setting active patient with", patient)
 		set_active_patient(patient=patient)
 
 		pat = gmCurrentPatient()
-		print pat['dob']
+		print(pat['dob'])
 		#pat['dob'] = 'test'
 
 #		staff = cStaff()
-#		print "setting active patient with", staff
+#		print("setting active patient with", staff)
 #		set_active_patient(patient=staff)
 
-		print "setting active patient with -1"
+		print("setting active patient with -1")
 		set_active_patient(patient=-1)
 	#--------------------------------------------------------
 	def test_dto_person():
@@ -2592,46 +2650,46 @@ if __name__ == '__main__':
 		dto.lastnames = 'Herberger'
 		dto.gender = 'male'
 		dto.dob = pyDT.datetime.now(tz=gmDateTime.gmCurrentLocalTimezone)
-		print dto
+		print(dto)
 
-		print dto['firstnames']
-		print dto['lastnames']
-		print dto['gender']
-		print dto['dob']
+		print(dto['firstnames'])
+		print(dto['lastnames'])
+		print(dto['gender'])
+		print(dto['dob'])
 
 		for key in dto.keys():
-			print key
+			print(key)
 	#--------------------------------------------------------
 	def test_identity():
 		# create patient
-		print '\n\nCreating identity...'
+		print('\n\nCreating identity...')
 		new_identity = create_identity(gender='m', dob='2005-01-01', lastnames='test lastnames', firstnames='test firstnames')
-		print 'Identity created: %s' % new_identity
+		print('Identity created: %s' % new_identity)
 
-		print '\nSetting title and gender...'
+		print('\nSetting title and gender...')
 		new_identity['title'] = 'test title';
 		new_identity['gender'] = 'f';
 		new_identity.save_payload()
-		print 'Refetching identity from db: %s' % cPerson(aPK_obj=new_identity['pk_identity'])
+		print('Refetching identity from db: %s' % cPerson(aPK_obj=new_identity['pk_identity']))
 
-		print '\nGetting all names...'
+		print('\nGetting all names...')
 		for a_name in new_identity.get_names():
-			print a_name
-		print 'Active name: %s' % (new_identity.get_active_name())
-		print 'Setting nickname...'
+			print(a_name)
+		print('Active name: %s' % (new_identity.get_active_name()))
+		print('Setting nickname...')
 		new_identity.set_nickname(nickname='test nickname')
-		print 'Refetching all names...'
+		print('Refetching all names...')
 		for a_name in new_identity.get_names():
-			print a_name
-		print 'Active name: %s' % (new_identity.get_active_name())		
+			print(a_name)
+		print('Active name: %s' % (new_identity.get_active_name()))
 
-		print '\nIdentity occupations: %s' % new_identity['occupations']
-		print 'Creating identity occupation...'
+		print('\nIdentity occupations: %s' % new_identity['occupations'])
+		print('Creating identity occupation...')
 		new_identity.link_occupation('test occupation')
-		print 'Identity occupations: %s' % new_identity['occupations']
+		print('Identity occupations: %s' % new_identity['occupations'])
 
-		print '\nIdentity addresses: %s' % new_identity.get_addresses()
-		print 'Creating identity address...'
+		print('\nIdentity addresses: %s' % new_identity.get_addresses())
+		print('Creating identity address...')
 		# make sure the state exists in the backend
 		new_identity.link_address (
 			number = 'test 1234',
@@ -2641,56 +2699,65 @@ if __name__ == '__main__':
 			region_code = u'SN',
 			country_code = u'DE'
 		)
-		print 'Identity addresses: %s' % new_identity.get_addresses()
+		print('Identity addresses: %s' % new_identity.get_addresses())
 
-		print '\nIdentity communications: %s' % new_identity.get_comm_channels()
-		print 'Creating identity communication...'
+		print('\nIdentity communications: %s' % new_identity.get_comm_channels())
+		print('Creating identity communication...')
 		new_identity.link_comm_channel('homephone', '1234566')
-		print 'Identity communications: %s' % new_identity.get_comm_channels()
+		print('Identity communications: %s' % new_identity.get_comm_channels())
 	#--------------------------------------------------------
 	def test_name():
 		for pk in range(1,16):
 			name = cPersonName(aPK_obj=pk)
-			print name.description
-			print '  ', name
+			print(name.description)
+			print('  ', name)
 	#--------------------------------------------------------
 	def test_gender_list():
 		genders, idx = get_gender_list()
-		print "\n\nRetrieving gender enum (tag, label, weight):"
+		print("\n\nRetrieving gender enum (tag, label, weight):")
 		for gender in genders:
-			print "%s, %s, %s" % (gender[idx['tag']], gender[idx['l10n_label']], gender[idx['sort_weight']])
+			print("%s, %s, %s" % (gender[idx['tag']], gender[idx['l10n_label']], gender[idx['sort_weight']]))
 	#--------------------------------------------------------
 	def test_export_area():
 		person = cPerson(aPK_obj = 12)
-		print person
-		print person.export_area
-		print person.export_area.items
+		print(person)
+		print(person.export_area)
+		print(person.export_area.items)
 	#--------------------------------------------------------
 	def test_ext_id():
 		person = cPerson(aPK_obj = 9)
-		print person.get_external_ids(id_type=u'Fachgebiet', issuer=u'Ärztekammer')
-		#print person.get_external_ids()
+		print(person.get_external_ids(id_type=u'Fachgebiet', issuer=u'Ärztekammer'))
+		#print(person.get_external_ids()
 	#--------------------------------------------------------
 	def test_vcf():
 		person = cPerson(aPK_obj = 12)
-		print person.export_as_vcard()
+		print(person.export_as_vcard())
+
+	#--------------------------------------------------------
+	def test_mecard():
+		person = cPerson(aPK_obj = 12)
+		print(person.MECARD)
+		mcf = person.export_as_mecard()
+		print(mcf)
+		#print(gmTools.create_qrcode(filename = mcf, qr_filename = None, verbose = True)
+		print(gmTools.create_qrcode(text = person.MECARD, qr_filename = None, verbose = True))
 
 	#--------------------------------------------------------
 	def test_current_patient():
 		pat = gmCurrentPatient()
-		print "pat.emr", pat.emr
+		print("pat.emr", pat.emr)
 
 	#--------------------------------------------------------
 	def test_ext_id():
 		person = cPerson(aPK_obj = 12)
-		print person.suggest_external_id(target = u'Orthanc')
+		print(person.suggest_external_id(target = u'Orthanc'))
 
 	#--------------------------------------------------------
 	def test_assimilate_identity():
 		patient = cPatient(12)
 		set_active_patient(patient = patient)
 		curr_pat = gmCurrentPatient()
-		other_pat = cIdentity(1111111)
+		other_pat = cPerson(1111111)
 		curr_pat.assimilate_identity(other_identity=None)
 
 	#--------------------------------------------------------
@@ -2705,12 +2772,13 @@ if __name__ == '__main__':
 	# module functions
 
 	#comms = get_comm_list()
-	#print "\n\nRetrieving communication media enum (id, description): %s" % comms
+	#print("\n\nRetrieving communication media enum (id, description): %s" % comms)
 	#test_export_area()
 	#test_ext_id()
 	#test_vcf()
+	test_mecard()
 	#test_ext_id()
 	#test_current_patient()
-	test_assimilate_identity()
+	#test_assimilate_identity()
 
 #============================================================
