@@ -16,6 +16,7 @@ from Gnumed.business import gmPerson
 
 
 _log = logging.getLogger('gm.person')
+
 #============================================================
 class cPatientSearcher_SQL:
 	"""UI independant i18n aware patient searcher."""
@@ -165,7 +166,7 @@ class cPatientSearcher_SQL:
 		raw = raw.strip().rstrip(u',').rstrip(u';').strip()
 
 		# "<digits>" - GNUmed patient PK or DOB
-		if regex.match(u"^(\s|\t)*\d+(\s|\t)*$", raw, flags = regex.LOCALE | regex.UNICODE):
+		if regex.match(u"^(\s|\t)*\d+(\s|\t)*$", raw, flags = regex.UNICODE):
 			_log.debug("[%s]: a PK or DOB" % raw)
 			tmp = raw.strip()
 			queries.append ({
@@ -193,7 +194,7 @@ class cPatientSearcher_SQL:
 			return queries
 
 		# "<d igi ts>" - DOB or patient PK
-		if regex.match(u"^(\d|\s|\t)+$", raw, flags = regex.LOCALE | regex.UNICODE):
+		if regex.match(u"^(\d|\s|\t)+$", raw, flags = regex.UNICODE):
 			_log.debug("[%s]: a DOB or PK" % raw)
 			queries.append ({
 				'cmd': u"SELECT *, %s::text AS match_type FROM dem.v_active_persons WHERE dem.date_trunc_utc('day'::text, dob) = dem.date_trunc_utc('day'::text, %s::timestamp with time zone) ORDER BY lastnames, firstnames, dob",
@@ -208,7 +209,7 @@ class cPatientSearcher_SQL:
 			return queries
 
 		# "#<di git  s>" - GNUmed patient PK
-		if regex.match(u"^(\s|\t)*#(\d|\s|\t)+$", raw, flags = regex.LOCALE | regex.UNICODE):
+		if regex.match(u"^(\s|\t)*#(\d|\s|\t)+$", raw, flags = regex.UNICODE):
 			_log.debug("[%s]: a PK or external ID" % raw)
 			tmp = raw.replace(u'#', u'')
 			tmp = tmp.strip()
@@ -235,7 +236,7 @@ class cPatientSearcher_SQL:
 			return queries
 
 		# "#<di/git s or c-hars>" - external ID
-		if regex.match(u"^(\s|\t)*#.+$", raw, flags = regex.LOCALE | regex.UNICODE):
+		if regex.match(u"^(\s|\t)*#.+$", raw, flags = regex.UNICODE):
 			_log.debug("[%s]: an external ID" % raw)
 			tmp = raw.replace(u'#', u'')
 			tmp = tmp.strip()
@@ -263,7 +264,7 @@ class cPatientSearcher_SQL:
 			return queries
 
 		# digits interspersed with "./-" or blank space - DOB
-		if regex.match(u"^(\s|\t)*\d+(\s|\t|\.|\-|/)*\d+(\s|\t|\.|\-|/)*\d+(\s|\t|\.)*$", raw, flags = regex.LOCALE | regex.UNICODE):
+		if regex.match(u"^(\s|\t)*\d+(\s|\t|\.|\-|/)*\d+(\s|\t|\.|\-|/)*\d+(\s|\t|\.)*$", raw, flags = regex.UNICODE):
 			_log.debug("[%s]: a DOB" % raw)
 			tmp = raw.strip()
 			while u'\t\t' in tmp: tmp = tmp.replace(u'\t\t', u' ')
@@ -278,7 +279,7 @@ class cPatientSearcher_SQL:
 			return queries
 
 		# " , <alpha>" - first name
-		if regex.match(u"^(\s|\t)*,(\s|\t)*([^0-9])+(\s|\t)*$", raw, flags = regex.LOCALE | regex.UNICODE):
+		if regex.match(u"^(\s|\t)*,(\s|\t)*([^0-9])+(\s|\t)*$", raw, flags = regex.UNICODE):
 			_log.debug("[%s]: a firstname" % raw)
 			tmp = self._normalize_soundalikes(raw[1:].strip())
 			cmd = u"""
@@ -300,7 +301,7 @@ SELECT DISTINCT ON (pk_identity) * FROM (
 			return queries
 
 		# "*|$<...>" - DOB
-		if regex.match(u"^(\s|\t)*(\*|\$).+$", raw, flags = regex.LOCALE | regex.UNICODE):
+		if regex.match(u"^(\s|\t)*(\*|\$).+$", raw, flags = regex.UNICODE):
 			_log.debug("[%s]: a DOB" % raw)
 			tmp = raw.replace(u'*', u'')
 			tmp = tmp.replace(u'$', u'')
@@ -385,7 +386,7 @@ SELECT DISTINCT ON (pk_identity) * FROM (
 
 		# "<CHARS>" - single name part
 		# yes, I know, this is culture specific (did you read the docs ?)
-		if regex.match(u"^(\s|\t)*[a-zäöüßéáúóçøA-ZÄÖÜÇØ]+(\s|\t)*$", search_term, flags = regex.LOCALE | regex.UNICODE):	
+		if regex.match(u"^(\s|\t)*[a-zäöüßéáúóçøA-ZÄÖÜÇØ]+(\s|\t)*$", search_term, flags = regex.UNICODE):
 			_log.debug("[%s]: a single name part", search_term)
 			# there's no intermediate whitespace due to the regex
 			cmd = u"""
@@ -456,7 +457,7 @@ SELECT DISTINCT ON (pk_identity) * FROM (
 					continue
 				# any digit signifies a date
 				# FIXME: what about "<40" ?
-				if regex.search(u"\d", part, flags = regex.LOCALE | regex.UNICODE):
+				if regex.search(u"\d", part, flags = regex.UNICODE):
 					date_count = date_count + 1
 					date_part = part
 				else:
@@ -484,8 +485,6 @@ SELECT DISTINCT ON (pk_identity) * FROM (
 						'cmd': u"SELECT DISTINCT ON (id_identity) d_vap.*, %s::text AS match_type FROM dem.v_active_persons d_vap, dem.names n WHERE d_vap.pk_identity = n.id_identity and lower(n.firstnames) ~* lower(%s) AND lower(n.lastnames) ~* lower(%s)",
 						'args': [_('name: last-first'), '^' + name_parts[1], '^' + name_parts[0]]
 					})
-					print "before nick"
-					print queries
 					# assumption: last nick
 					queries.append ({
 						'cmd': u"SELECT DISTINCT ON (id_identity) d_vap.*, %s::text AS match_type FROM dem.v_active_persons d_vap, dem.names n WHERE d_vap.pk_identity = n.id_identity and n.preferred ~ %s AND n.lastnames ~ %s",
@@ -495,8 +494,6 @@ SELECT DISTINCT ON (pk_identity) * FROM (
 						'cmd': u"SELECT DISTINCT ON (id_identity) d_vap.*, %s::text AS match_type FROM dem.v_active_persons d_vap, dem.names n WHERE d_vap.pk_identity = n.id_identity and lower(n.preferred) ~* lower(%s) AND lower(n.lastnames) ~* lower(%s)",
 						'args': [_('name: last-nick'), '^' + name_parts[1], '^' + name_parts[0]]
 					})
-					print "after nick"
-					print queries
 					# name parts anywhere inside name - third order query ...
 					queries.append ({
 						'cmd': u"""SELECT DISTINCT ON (id_identity)
@@ -580,7 +577,7 @@ SELECT DISTINCT ON (pk_identity) * FROM (
 				if part.strip() == u'':
 					continue
 				# any digits ?
-				if regex.search(u"\d+", part, flags = regex.LOCALE | regex.UNICODE):
+				if regex.search(u"\d+", part, flags = regex.UNICODE):
 					# FIXME: parse out whitespace *not* adjacent to a *word*
 					date_parts.append(part)
 				else:
@@ -742,6 +739,7 @@ SELECT DISTINCT ON (pk_identity) * FROM (
 ) AS ordered_list""" % (_('full name'), where_clause)
 
 		return ({'cmd': query, 'args': args})
+
 #============================================================
 def ask_for_patient():
 	"""Text mode UI function to ask for patient."""
@@ -758,21 +756,23 @@ def ask_for_patient():
 		pats = person_searcher.get_patients(search_term = search_fragment)
 
 		if (pats is None) or (len(pats) == 0):
-			print "No patient matches the query term."
+			print "No patient matches the search term."
 			print ""
 			continue
 
 		if len(pats) > 1:
-			print "Several patients match the query term:"
+			print "Several patients match the search term:"
 			print ""
 			for pat in pats:
 				print pat
 				print ""
+			print "Please refine the search term so it matches one patient only."
 			continue
 
 		return pats[0]
 
 	return None
+
 #============================================================
 # main/testing
 #============================================================
@@ -899,7 +899,7 @@ if __name__ == '__main__':
 			myPatient.export_as_gdt(filename='apw.gdt', encoding = 'cp850')
 #		docs = myPatient.get_document_folder()
 #		print "docs     ", docs
-#		emr = myPatient.get_emr()
+#		emr = myPatient.emr
 #		print "EMR      ", emr
 	#--------------------------------------------------------
 	#test_patient_search_queries()
