@@ -26,11 +26,7 @@ _log = logging.getLogger('gm.inbox')
 #============================================================
 # provider message inbox
 #------------------------------------------------------------
-_SQL_get_inbox_messages = u"""
-SELECT * FROM
-	dem.v_message_inbox d_vi
-		LEFT OUTER JOIN dem.v_persons d_vp ON (d_vi.pk_patient = d_vp.pk_identity)
-WHERE %s"""
+_SQL_get_inbox_messages = u"""SELECT * FROM dem.v_message_inbox d_vi WHERE %s"""
 
 class cInboxMessage(gmBusinessDBObject.cBusinessDBObject):
 
@@ -101,7 +97,7 @@ class cInboxMessage(gmBusinessDBObject.cBusinessDBObject):
 				self._payload[self._idx['lastnames']],
 				self._payload[self._idx['firstnames']],
 				gmTools.coalesce(self._payload[self._idx['l10n_gender']], u'', u' (%s)'),
-				gmDateTime.pydt_strftime(self._payload[self._idx['dob_only']], u'%Y %b %d', none_str = u''),
+				gmDateTime.pydt_strftime(self._payload[self._idx['dob']], u'%Y %b %d', none_str = u''),
 				self._payload[self._idx['pk_patient']]
 			))
 
@@ -258,6 +254,7 @@ def get_inbox_messages(pk_staff=None, pk_patient=None, include_without_provider=
 	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}], get_col_idx = True)
 
 	return [ cInboxMessage(row = {'data': r, 'idx': idx, 'pk_field': 'pk_inbox_message'}) for r in rows ]
+
 #------------------------------------------------------------
 def create_inbox_message(message_type=None, subject=None, patient=None, staff=None, message_category=u'clinical'):
 
@@ -288,12 +285,14 @@ def create_inbox_message(message_type=None, subject=None, patient=None, staff=No
 	rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}], return_data = True, get_col_idx = False)
 
 	return cInboxMessage(aPK_obj = rows[0]['pk'])
+
 #------------------------------------------------------------
 def delete_inbox_message(inbox_message=None):
 	args = {'pk': inbox_message}
 	cmd = u"DELETE FROM dem.message_inbox WHERE pk = %(pk)s"
 	gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}])
 	return True
+
 #------------------------------------------------------------
 def create_inbox_item_type(message_type=None, category=u'clinical'):
 
