@@ -404,12 +404,12 @@ def create_generic_vaccine_sql(version, include_indications_mapping=False):
 #============================================================
 # vaccine related code
 #------------------------------------------------------------
-_sql_fetch_vaccine = u"""SELECT * FROM ref.v_vaccines WHERE %s"""
+_SQL_get_vaccine_fields = u"""SELECT * FROM ref.v_vaccines WHERE %s"""
 
 class cVaccine(gmBusinessDBObject.cBusinessDBObject):
 	"""Represents one vaccine."""
 
-	_cmd_fetch_payload = _sql_fetch_vaccine % u"pk_vaccine = %s"
+	_cmd_fetch_payload = _SQL_get_vaccine_fields % u"pk_vaccine = %s"
 
 	_cmds_store_payload = [
 		u"""UPDATE ref.vaccine SET
@@ -487,10 +487,11 @@ class cVaccine(gmBusinessDBObject.cBusinessDBObject):
 	is_in_use = property(_get_is_in_use, lambda x:x)
 
 #------------------------------------------------------------
-def create_vaccine(pk_drug_product=None, product_name=None, indications=None):
+def create_vaccine(pk_drug_product=None, product_name=None, indications=None, is_live=None):
+
+	assert (is_live is not None), '<is_live> must not be <None>'
 
 	conn = gmPG2.get_connection(readonly = False)
-
 	if pk_drug_product is None:
 		#prep = _('vaccine')
 		prep = u'vaccine'
@@ -507,9 +508,8 @@ def create_vaccine(pk_drug_product=None, product_name=None, indications=None):
 		vacc_prod['atc'] = u'J07'
 		vacc_prod.save(conn = conn)
 		pk_drug_product = vacc_prod['pk_drug_product']
-
-	cmd = u'INSERT INTO ref.vaccine (fk_drug_product) values (%(pk_drug_product)s) RETURNING pk'
-	queries = [{'cmd': cmd, 'args': {'pk_drug_product': pk_drug_product}}]
+	cmd = u'INSERT INTO ref.vaccine (fk_drug_product, is_live) values (%(pk_drug_product)s, %(live)s) RETURNING pk'
+	queries = [{'cmd': cmd, 'args': {'pk_drug_product': pk_drug_product, 'live': is_live}}]
 	rows, idx = gmPG2.run_rw_queries(link_obj = conn, queries = queries, get_col_idx = False, return_data = True, end_tx = True)
 	conn.close()
 	return cVaccine(aPK_obj = rows[0]['pk'])
@@ -532,9 +532,9 @@ def delete_vaccine(vaccine=None):
 def get_vaccines(order_by=None):
 
 	if order_by is None:
-		cmd = _sql_fetch_vaccine % u'TRUE'
+		cmd = _SQL_get_vaccine_fields % u'TRUE'
 	else:
-		cmd = _sql_fetch_vaccine % (u'TRUE\nORDER BY %s' % order_by)
+		cmd = _SQL_get_vaccine_fields % (u'TRUE\nORDER BY %s' % order_by)
 
 	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd}], get_col_idx = True)
 
@@ -543,11 +543,11 @@ def get_vaccines(order_by=None):
 #============================================================
 # vaccination related classes
 #============================================================
-sql_fetch_vaccination = u"""SELECT * FROM clin.v_vaccinations WHERE %s"""
+_SQL_get_vaccination_fields = u"""SELECT * FROM clin.v_vaccinations WHERE %s"""
 
 class cVaccination(gmBusinessDBObject.cBusinessDBObject):
 
-	_cmd_fetch_payload = sql_fetch_vaccination % u"pk_vaccination = %s"
+	_cmd_fetch_payload = _SQL_get_vaccination_fields % u"pk_vaccination = %s"
 
 	_cmds_store_payload = [
 		u"""UPDATE clin.vaccination SET
@@ -623,6 +623,13 @@ class cVaccination(gmBusinessDBObject.cBusinessDBObject):
 
 	vaccine = property(_get_vaccine, lambda x:x)
 
+#------------------------------------------------------------
+def get_vaccinations():
+	cmd = _SQL_get_vaccination_fields % 'True'
+	args = {}
+	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd}], get_col_idx = True)
+	return [ cVaccination(row = {'data': r, 'idx': idx, 'pk_field': 'pk_vaccine'}) for r in rows ]
+
 #------------------------------------------------------------
 def create_vaccination(encounter=None, episode=None, vaccine=None, batch_no=None):
 
@@ -677,34 +684,33 @@ def format_latest_vaccinations(output_format=u'latex', emr=None):
 def __format_latest_vaccinations_latex(vaccinations=None):
 
 	if len(vaccinations) == 0:
-		return u'\\noindent %s' % _('No vaccinations to format.')
+		return u'\\noindent %s' % _('No vaccinations recorded.')
 
 	tex =  u'\\noindent %s {\\tiny (%s)\\par}\n' % (_('Latest vaccinations'), _('per target condition'))
 	tex += u'\n'
 	tex += u'\\noindent \\begin{tabular}{|l|l|l|l|l|l|}\n'
 	tex += u'\\hline\n'
-	tex += u'%s & %s & {\\footnotesize %s} & {\\footnotesize %s} & {\\footnotesize %s\\footnotemark} & {\\footnotesize %s\\footnotemark} \\\\ \n' % (
+	tex += u'%s & %s & {\\footnotesize %s} & {\\footnotesize %s} & {\\footnotesize %s\\footnotemark} & {\\footnotesize $\\Sigma$\\footnotemark}\\\\\n' % (
 		_('Target'),
 		_('Last given'),
 		_('Vaccine'),
 		_('Lot \#'),
-		_('SoaP'),
-		gmTools.u_sum
+		_('SoaP')
 	)
 	tex += u'\\hline\n'
 	tex += u'\n'
 	tex += u'\\hline\n'
-	tex += u'%s'
+	tex += u'%s'			# this is where the actual vaccination rows end up
 	tex += u'\n'
 	tex += u'\\end{tabular}\n'
 	tex += u'\n'
-	tex += u'\\addtocounter{footnote}{-1} \n'
-	tex += u'\\footnotetext{%s} \n' % _('SoaP -- "S"ubjective: vaccination was remembered by patient. "P"lan: vaccination was administered in the practice or copied from trustworthy records.')
-	tex += u'\\addtocounter{footnote}{1} \n'
-	tex += u'\\footnotetext{%s -- %s} \n' % (gmTools.u_sum, _('Total number of vaccinations recorded for the corresponding target condition.'))
+	tex += u'\\addtocounter{footnote}{-1}\n'
+	tex += u'\\footnotetext{%s}\n' % _('SoaP -- "S"ubjective: vaccination was remembered by patient. "P"lan: vaccination was administered in the practice or copied from trustworthy records.')
+	tex += u'\\addtocounter{footnote}{1}\n'
+	tex += u'\\footnotetext{$\\Sigma$ -- %s}\n' % _('Total number of vaccinations recorded for the corresponding target condition.')
 	tex += u'\n'
 
-	row_template = u'%s & %s & {\\scriptsize %s} & {\\scriptsize %s} & {\\scriptsize %s} & {\\scriptsize %s} \\\\ \n'
+	row_template = u'%s & %s & {\\scriptsize %s} & {\\scriptsize %s} & {\\scriptsize %s} & {\\scriptsize %s}\\\\\n'
 	lines = u''
 	targets = sorted(vaccinations.keys())
 	for target in targets:
@@ -718,12 +724,12 @@ def __format_latest_vaccinations_latex(vaccinations=None):
 			target_count
 		)
 		if vacc['site'] is not None:
-			lines += u' & \\multicolumn{5}{l|}{\\scriptsize %s: %s\\par} \\\\ \n' % (_('Injection site'), vacc['site'].strip())
+			lines += u' & \\multicolumn{5}{l|}{\\scriptsize %s: %s\\par}\\\\\n' % (_('Injection site'), vacc['site'].strip())
 		if vacc['reaction'] is not None:
-			lines += u' & \\multicolumn{5}{l|}{\\scriptsize %s: %s\\par} \\\\ \n' % (_('Reaction'), vacc['reaction'].strip())
+			lines += u' & \\multicolumn{5}{l|}{\\scriptsize %s: %s\\par}\\\\\n' % (_('Reaction'), vacc['reaction'].strip())
 		if vacc['comment'] is not None:
-			lines += u' & \\multicolumn{5}{l|}{\\scriptsize %s: %s\\par} \\\\ \n' % (_('Comment'), vacc['comment'].strip())
-		lines += u'\\hline \n'
+			lines += u' & \\multicolumn{5}{l|}{\\scriptsize %s: %s\\par}\\\\\n' % (_('Comment'), vacc['comment'].strip())
+		lines += u'\\hline\n'
 
 	return tex % lines
 
@@ -846,6 +852,6 @@ if __name__ == '__main__':
 	#test_due_booster()
 
 	#test_get_vaccines()
-	#test_get_vaccinations()
+	test_get_vaccinations()
 	#test_create_generic_vaccine_sql()
-	test_write_generic_vaccine_sql(sys.argv[2], sys.argv[3])
+	#test_write_generic_vaccine_sql(sys.argv[2], sys.argv[3])
