@@ -33,7 +33,8 @@ CONF="--conf-file=gm-from-vcs.conf"
 
 # options useful for development and debugging:
 TS=`date +%m_%d-%H_%M_%S`
-DEV_OPTS="--log-file=gm-vcs-${TS}-$$.log --override-schema-check --skip-update-check --local-import --debug"
+DEV_OPTS="--log-file=gm-vcs-${TS}-$$.log --override-schema-check --local-import --debug"
+# --tool=check_enc_epi_xref
 # --profile=gm-from-vcs.prof
 
 # options for running from released tarballs:
@@ -49,14 +50,14 @@ echo "-------------------------------------------------"
 echo "Running from Git branch: "`git branch | grep \*`
 echo "-------------------------------------------------"
 echo "config file: ${CONF}"
-##python -Q warn -3 gnumed.py ${CONF} ${DEV_OPTS} $@
-##python -Q warn -3 gnumed.py ${CONF} ${DEV_OPTS} $@ 2> >(grep -v wx > gm-vcs-py2to3_warnings.log) # 1>&2)
-#echo "options: ${DEV_OPTS}"
-#python -Q warn -3 gnumed.py ${CONF} ${DEV_OPTS} $@ |& tee gm-vcs-py2to3_warnings.log
+echo "options: ${DEV_OPTS}"
+#python -Q warn -3 gnumed.py ${CONF} ${DEV_OPTS} $@
+#python -Q warn -3 gnumed.py ${CONF} ${DEV_OPTS} $@ 2> >(grep -v wx > gm-vcs-py2to3_warnings.log) # 1>&2)
+#python -Q warn -3 gnumed.py ${CONF} ${DEV_OPTS} $@ |& tee gm-vcs-console_output.log
+#python -Q warn -3 gnumed.py ${CONF} ${DEV_OPTS} $@
 
 
 # - *released* tarball version:
-echo "options: ${TARBALL_OPTS}"
 python gnumed.py ${CONF} ${TARBALL_OPTS} $@
 
 # - production version (does not use tarball files !):
