@@ -24,6 +24,7 @@ import types
 import logging
 import datetime as pydt
 import re as regex
+import threading
 
 
 # GNUmed
@@ -88,7 +89,7 @@ FixedOffsetTimezone = dbapi.tz.FixedOffsetTimezone
 _default_dsn = None
 _default_login = None
 
-default_database = 'gnumed_v21'
+default_database = 'gnumed_v22'
 
 postgresql_version_string = None
 postgresql_version = None			# accuracy: major.minor
@@ -123,7 +124,8 @@ known_schema_hashes = {
 	#19: '9765373098b03fb208332498f34cd4b5' # until 19.11
 	19: '57f009a159f55f77525cc0291e0c8b60', # starting with 19.12
 	20: 'baed1901ed4c2f272b56c8cb2c6d88e8',
-	21: 'e6a51a89dd22b75b61ead8f7083f251f'
+	21: 'e6a51a89dd22b75b61ead8f7083f251f',
+	22: 'bf45f01327fb5feb2f5d3c06ba4a6792'
 }
 
 map_schema_hash2version = {
@@ -148,7 +150,8 @@ map_schema_hash2version = {
 	#'9765373098b03fb208332498f34cd4b5': 19 # until 19.11
 	'57f009a159f55f77525cc0291e0c8b60': 19, # starting with 19.12
 	'baed1901ed4c2f272b56c8cb2c6d88e8': 20,
-	'e6a51a89dd22b75b61ead8f7083f251f': 21
+	'e6a51a89dd22b75b61ead8f7083f251f': 21,
+	'bf45f01327fb5feb2f5d3c06ba4a6792': 22
 }
 
 map_client_branch2required_db_version = {
@@ -166,7 +169,8 @@ map_client_branch2required_db_version = {
 	u'1.3': 18,
 	u'1.4': 19,
 	u'1.5': 20,
-	u'1.6': 21
+	u'1.6': 21,
+	u'1.7': 22
 }
 
 map_psyco_tx_status2str = [
@@ -293,6 +297,29 @@ WHERE
 	)
 """
 
+SQL_get_pk_col_def = u"""
+SELECT
+	pg_attribute.attname
+		AS pk_col,
+	format_type(pg_attribute.atttypid, pg_attribute.atttypmod)
+		AS pk_type
+FROM pg_index, pg_class, pg_attribute, pg_namespace
+WHERE
+	pg_class.oid = %(table)s::regclass
+		AND
+	indrelid = pg_class.oid
+		AND
+--	nspname = %%(schema)s
+--		AND
+	pg_class.relnamespace = pg_namespace.oid
+		AND
+	pg_attribute.attrelid = pg_class.oid
+		AND
+	pg_attribute.attnum = any(pg_index.indkey)
+		AND
+	indisprimary
+"""
+
 # =======================================================================
 # module globals API
 # =======================================================================
@@ -503,12 +530,13 @@ def request_login_params():
 		raise Exception('Cannot request login parameters.')
 
 	# are we inside X ?
-	# (if we aren't wxGTK will crash hard at
-	# C-level with "can't open Display")
+	# if we aren't wxGTK will crash hard at the C-level with "can't open Display"
 	if u'DISPLAY' in os.environ:
 		# try wxPython GUI
-		try: return __request_login_params_gui_wx()
-		except: pass
+		try:
+			return __request_login_params_gui_wx()
+		except:
+			pass
 
 	# well, either we are on the console or
 	# wxPython does not work, use text mode
@@ -634,6 +662,7 @@ def database_schema_compatible(link_obj=None, version=None, verbose=True):
 		return False
 	_log.info('detected schema version [%s], hash [%s]' % (map_schema_hash2version[rows[0]['md5']], rows[0]['md5']))
 	return True
+
 #------------------------------------------------------------------------
 def get_schema_version(link_obj=None):
 	rows, idx = run_ro_queries(link_obj=link_obj, queries = [{'cmd': u'select md5(gm.concat_table_structure()) as md5'}])
@@ -641,14 +670,17 @@ def get_schema_version(link_obj=None):
 		return map_schema_hash2version[rows[0]['md5']]
 	except KeyError:
 		return u'unknown database schema version, MD5 hash is [%s]' % rows[0]['md5']
+
 #------------------------------------------------------------------------
 def get_schema_structure(link_obj=None):
 	rows, idx = run_ro_queries(link_obj=link_obj, queries = [{'cmd': u'select gm.concat_table_structure()'}])
 	return rows[0][0]
+
 #------------------------------------------------------------------------
 def get_schema_hash(link_obj=None):
 	rows, idx = run_ro_queries(link_obj=link_obj, queries = [{'cmd': u'select md5(gm.concat_table_structure()) as md5'}])
 	return rows[0]['md5']
+
 #------------------------------------------------------------------------
 def get_schema_revision_history(link_obj=None):
 
@@ -677,6 +709,7 @@ def get_schema_revision_history(link_obj=None):
 def get_current_user():
 	rows, idx = run_ro_queries(queries = [{'cmd': u'select CURRENT_USER'}])
 	return rows[0][0]
+
 #------------------------------------------------------------------------
 def get_foreign_keys2column(schema='public', table=None, column=None, link_obj=None):
 	"""Get the foreign keys pointing to schema.table.column.
@@ -684,20 +717,26 @@ def get_foreign_keys2column(schema='public', table=None, column=None, link_obj=N
 	Does not properly work with multi-column FKs.
 	GNUmed doesn't use any, however.
 	"""
+	args = {
+		'schema': schema,
+		'tbl': table,
+		'col': column
+	}
 	cmd = u"""
-select
-	%(schema)s as referenced_schema,
-	%(tbl)s as referenced_table,
-	%(col)s as referenced_column,
-	pgc.confkey as referenced_column_list,
-	pgc.conrelid::regclass as referencing_table,
-	pgc.conkey as referencing_column_list,
-	(select attname from pg_attribute where attnum = pgc.conkey[1] and attrelid = pgc.conrelid) as referencing_column
-from
+SELECT
+	%(schema)s AS referenced_schema,
+	%(tbl)s AS referenced_table,
+	%(col)s AS referenced_column,
+	pgc.confkey AS referenced_column_list,
+
+	pgc.conrelid::regclass AS referencing_table,
+	pgc.conkey AS referencing_column_list,
+	(select attname from pg_attribute where attnum = pgc.conkey[1] and attrelid = pgc.conrelid) AS referencing_column
+FROM
 	pg_constraint pgc
-where
+WHERE
 	pgc.contype = 'f'
-		and
+		AND
 	pgc.confrelid = (
 		select oid from pg_class where relname = %(tbl)s and relnamespace = (
 			select oid from pg_namespace where nspname = %(schema)s
@@ -714,13 +753,6 @@ where
 			attname = %(col)s
 	) = any(pgc.confkey)
 """
-
-	args = {
-		'schema': schema,
-		'tbl': table,
-		'col': column
-	}
-
 	rows, idx = run_ro_queries (
 		link_obj = link_obj,
 		queries = [
@@ -787,12 +819,14 @@ where
 	)"""
 	rows, idx = run_ro_queries(link_obj = link_obj, queries = [{'cmd': cmd, 'args': {'schema': schema, 'table': table}}])
 	return rows
+
 #------------------------------------------------------------------------
 def schema_exists(link_obj=None, schema=u'gm'):
 	cmd = u"""SELECT EXISTS (SELECT 1 FROM pg_namespace WHERE nspname = %(schema)s)"""
 	args = {'schema': schema}
 	rows, idx = run_ro_queries(link_obj = link_obj, queries = [{'cmd': cmd, 'args': args}])
 	return rows[0][0]
+
 #------------------------------------------------------------------------
 def table_exists(link_obj=None, schema=None, table=None):
 	"""Returns false, true."""
@@ -1132,14 +1166,21 @@ def row_is_locked(table=None, pk=None):
 	return False
 
 #------------------------------------------------------------------------
-def bytea2file(data_query=None, filename=None, chunk_size=0, data_size=None, data_size_query=None):
-	outfile = file(filename, 'wb')
-	result = bytea2file_object(data_query=data_query, file_obj=outfile, chunk_size=chunk_size, data_size=data_size, data_size_query=data_size_query)
+def bytea2file(data_query=None, filename=None, chunk_size=0, data_size=None, data_size_query=None, conn=None):
+	outfile = io.open(filename, 'wb')
+	result = bytea2file_object (
+		data_query = data_query,
+		file_obj = outfile,
+		chunk_size = chunk_size,
+		data_size = data_size,
+		data_size_query = data_size_query,
+		conn = conn
+	)
 	outfile.close()
 	return result
 
 #------------------------------------------------------------------------
-def bytea2file_object(data_query=None, file_obj=None, chunk_size=0, data_size=None, data_size_query=None):
+def bytea2file_object(data_query=None, file_obj=None, chunk_size=0, data_size=None, data_size_query=None, conn=None):
 	"""Store data from a bytea field into a file.
 
 	<data_query>
@@ -1171,7 +1212,8 @@ def bytea2file_object(data_query=None, file_obj=None, chunk_size=0, data_size=No
 	# reported to be fixed > v7.4.
 	# further tests reveal that at least on PG 8.0 this bug still
 	# manifests itself
-	conn = get_raw_connection(readonly=True)
+	if conn is None:
+		conn = get_raw_connection(readonly = True)
 
 	if data_size is None:
 		rows, idx = run_ro_queries(link_obj = conn, queries = [data_size_query])
@@ -1249,7 +1291,8 @@ def file2bytea(query=None, filename=None, args=None, conn=None, file_md5=None):
 	infile.close()
 	if args is None:
 		args = {}
-	args['data'] = buffer(data_as_byte_string)
+	# really still needed for BYTEA input ?
+	args['data'] = memoryview(data_as_byte_string)
 	del(data_as_byte_string)
 
 	# insert the data
@@ -1447,7 +1490,8 @@ def file2bytea_overlay(query=None, args=None, filename=None, conn=None, md5_quer
 		args['start'] = chunk_start
 		args['size'] = chunk_size
 		data_as_byte_string = infile.read(chunk_size)
-		args['data'] = buffer(data_as_byte_string)
+		# really still needed for BYTEA input ?
+		args['data'] = memoryview(data_as_byte_string)
 		del(data_as_byte_string)
 		try:
 			rows, idx = run_rw_queries(link_obj = conn, queries = [{'cmd': query, 'args': args}], end_tx = False, return_data = False)
@@ -1463,7 +1507,8 @@ def file2bytea_overlay(query=None, args=None, filename=None, conn=None, md5_quer
 		args['start'] = chunk_start
 		args['size'] = remainder
 		data_as_byte_string = infile.read(remainder)
-		args['data'] = buffer(data_as_byte_string)
+		# really still needed for BYTEA input ?
+		args['data'] = memoryview(data_as_byte_string)
 		del(data_as_byte_string)
 		try:
 			rows, idx = run_rw_queries(link_obj = conn, queries = [{'cmd': query, 'args': args}], end_tx = False, return_data = False)
@@ -2004,33 +2049,47 @@ def run_insert(link_obj=None, schema=None, table=None, values=None, returning=No
 # connection handling API
 # -----------------------------------------------------------------------
 class cConnectionPool(psycopg2.pool.PersistentConnectionPool):
-	"""
-	GNUmed database connection pool.
+	"""GNUmed database connection pool.
 
-	Extends psycopg2's PersistentConnectionPool with
+	Extends psycopg2's ThreadedConnectionPool with
 	a custom _connect() function. Supports one connection
-	per thread - which also ties it to one particular DSN.
-	"""
+	per thread - which also ties it to one particular DSN."""
 	#--------------------------------------------------
 	def _connect(self, key=None):
-
-		conn = get_raw_connection(dsn = self._kwargs['dsn'], verbose = self._kwargs['verbose'], readonly=True)
-
+		_log.debug('conn request with key [%s]', key)
+		conn = get_raw_connection(dsn = self._kwargs['dsn'], verbose = self._kwargs['verbose'], readonly = True)
+		# monkey patching close()
 		conn.original_close = conn.close
 		conn.close = _raise_exception_on_ro_conn_close
-
 		if key is not None:
 			self._used[key] = conn
 			self._rused[id(conn)] = key
 		else:
 			self._pool.append(conn)
-
 		return conn
+
+	#--------------------------------------------------
+	def discard_connection(self, key=None):
+		if key is None:
+			key = threading.current_thread().ident
+		try:
+			conn = self._used[key]
+		except KeyError:
+			_log.error(u'no such key in connection pool: %s', key)
+			_log.debug(u'available keys: %s', self._used.keys())
+			return
+		del self._used[key]
+		del self._rused[id(conn)]
+		conn.original_close()
+
 	#--------------------------------------------------
 	def shutdown(self):
 		for conn_key in self._used.keys():
+			conn = self._used[conn_key]
+			if conn.closed != 0:
+				continue
 			_log.debug('closing pooled database connection, pool key: %s, backend PID: %s', conn_key, self._used[conn_key].get_backend_pid())
-			self._used[conn_key].original_close()
+			conn.original_close()
 
 # -----------------------------------------------------------------------
 def get_raw_connection(dsn=None, verbose=False, readonly=True, connection_name=None, autocommit=False):
@@ -2054,14 +2113,14 @@ def get_raw_connection(dsn=None, verbose=False, readonly=True, connection_name=N
 	if u' client_encoding=' not in dsn:
 		dsn += u' client_encoding=utf8'
 
-	if connection_name is None:
-		if u' application_name' not in dsn:
-			dsn += u" application_name=GNUmed"
-	else:
-		if u' application_name' not in dsn:
+	if u' application_name' not in dsn:
+		if connection_name is None:
+			dsn += u" application_name=GNUmed-[%s]"	% threading.current_thread().name.replace(u' ', u'_')
+		else:
 			dsn += u" application_name=%s" % connection_name
 
 	try:
+		# DictConnection now _is_ a real dictionary
 		conn = dbapi.connect(dsn=dsn, connection_factory=psycopg2.extras.DictConnection)
 	except dbapi.OperationalError, e:
 
@@ -2114,7 +2173,6 @@ def get_raw_connection(dsn=None, verbose=False, readonly=True, connection_name=N
 			_log_PG_settings(curs = curs)
 		curs.close()
 		conn.commit()
-
 	# - verify PG understands client time zone
 	if _default_client_timezone is None:
 		__detect_client_timezone(conn = conn)
@@ -2154,7 +2212,12 @@ def get_connection(dsn=None, readonly=True, encoding=None, verbose=False, pooled
 			)
 		else:
 			log_ro_conn = False
-		conn = __ro_conn_pool.getconn()
+		try:
+			conn = __ro_conn_pool.getconn()
+		except psycopg2.pool.PoolError:
+			_log.exception('falling back to non-pooled connection')
+			conn = get_raw_connection(dsn = dsn, verbose = verbose, readonly = readonly, connection_name = connection_name, autocommit = autocommit)
+			log_ro_conn = True
 		if log_ro_conn:
 			[ _log.debug(line) for line in capture_conn_state(conn = conn).split(u'\n') ]
 	else:
@@ -2203,6 +2266,12 @@ def get_connection(dsn=None, readonly=True, encoding=None, verbose=False, pooled
 
 	return conn
 
+#-----------------------------------------------------------------------
+def discard_pooled_connection(conn_key=None):
+	if __ro_conn_pool is None:
+		return
+	__ro_conn_pool.discard_connection(key = conn_key)
+
 #-----------------------------------------------------------------------
 def shutdown():
 	if __ro_conn_pool is None:
@@ -2869,17 +2938,18 @@ if __name__ == "__main__":
 
 	#--------------------------------------------------------------------
 	def test_get_foreign_key_details():
+		schema = u'clin'
+		table = u'episode'
+		col = u'pk'
+		print 'column %s.%s.%s is referenced by:' % (schema, table, col)
 		for row in get_foreign_keys2column (
-			schema = u'clin',
-			table = u'episode',
-			column = u'pk'
+			schema = schema,
+			table = table,
+			column = col
 		):
-			print '%s.%s references %s.%s.%s' % (
+			print ' <- %s.%s' % (
 				row['referencing_table'],
-				row['referencing_column'],
-				row['referenced_schema'],
-				row['referenced_table'],
-				row['referenced_column']
+				row['referencing_column']
 			)
 
 	#--------------------------------------------------------------------
@@ -2978,6 +3048,7 @@ SELECT to_timestamp (foofoo,'YYMMDD.HH24MI') FROM (
 		print " locked:", row_is_locked(table = 'dem.identity', pk = 12)
 
 		conn.close()
+
 	#--------------------------------------------------------------------
 	def test_get_foreign_key_names():
 		print get_foreign_key_names (
@@ -2988,6 +3059,7 @@ SELECT to_timestamp (foofoo,'YYMMDD.HH24MI') FROM (
 			target_table = 'identity',
 			target_column = 'pk'
 		)
+
 	#--------------------------------------------------------------------
 	def test_get_index_name():
 		print get_index_name(indexed_table = 'clin.vaccination', indexed_column = 'fk_episode')
@@ -3013,7 +3085,7 @@ SELECT to_timestamp (foofoo,'YYMMDD.HH24MI') FROM (
 	#test_sanitize_pg_regex()
 	#test_is_pg_interval()
 	#test_sanity_check_time_skew()
-	#test_get_foreign_key_details()
+	test_get_foreign_key_details()
 	#test_get_foreign_key_names()
 	#test_get_index_name()
 	#test_set_user_language()
@@ -3026,7 +3098,7 @@ SELECT to_timestamp (foofoo,'YYMMDD.HH24MI') FROM (
 	#test_file2bytea_overlay()
 	#test_file2bytea_copy_from()
 	#test_file2bytea_lo()
-	test_faulty_SQL()
+	#test_faulty_SQL()
 	#test_log_settings()
 
 # ======================================================================
