@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2009, 2010, 2011  Rickard Lindberg, Roger Lindberg
+# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018  Rickard Lindberg, Roger Lindberg
 #
 # This file is part of Timeline.
 #
@@ -19,11 +19,11 @@
 
 import wx
 
-from timelinelib.meta.version import get_version
+from timelinelib.meta.version import get_full_version
 
 
 APPLICATION_NAME = "Timeline"
-COPYRIGHT_TEXT = "Copyright (C) 2009, 2010, 2011 The %s Authors" % APPLICATION_NAME
+COPYRIGHT_TEXT = "Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018 The %s Authors" % APPLICATION_NAME
 APPLICATION_DESCRIPTION = "Timeline is a free, cross-platform application for displaying and navigating events on a timeline."
 WEBSITE = "http://thetimelineproj.sourceforge.net/"
 DEVELOPERS = [
@@ -35,8 +35,12 @@ DEVELOPERS = [
     u"    Glenn J. Mason",
     u"    Joe Gilmour",
     u"    Thomas Mohr",
+    u"    Linostar",
+    u"    Norbert Langermann",
 ]
 TRANSLATORS = [
+    u"Basque:",
+    u"    Urtzi Odriozola",
     u"Brazilian Portuguese:",
     u"    Leo Frigo",
     u"    Marcelo Ribeiro de Almeida",
@@ -52,6 +56,9 @@ TRANSLATORS = [
     u"    Nils Steinger",
     u"    Daniel Winzen",
     u"    cmdrhenner",
+    u"    Norbert Langermann",
+    u"Greek:",
+    u"    Yannis Kaskamanidis",
     u"Hebrew:",
     u"    Yaron Shahrabani",
     u"Lithuanian:",
@@ -92,10 +99,10 @@ You should have received a copy of the GNU General Public License
 along with Timeline.  If not, see <http://www.gnu.org/licenses/>."""
 
 
-def display_about_dialog():
+def display_about_dialog(args, *kwargs):
     info = wx.AboutDialogInfo()
     info.Name = APPLICATION_NAME
-    info.Version = get_version()
+    info.Version = get_full_version()
     info.Copyright = COPYRIGHT_TEXT
     info.Description = APPLICATION_DESCRIPTION
     info.WebSite = (WEBSITE, "%s Website" % APPLICATION_NAME)
