@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010, 2011  Rickard Lindberg, Roger Lindberg
+# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018  Rickard Lindberg, Roger Lindberg
 #
 # This file is part of Timeline.
 #
@@ -17,27 +17,20 @@
 
 
 class DrawingAreaProxy():
-    
+
     def __init__(self, creator):
-        from timelinelib.wxgui.dialogs.mainframe import MainFrame
+        from timelinelib.wxgui.frames.mainframe.mainframe import MainFrame
         if isinstance(creator, MainFrame):
-            self.drawing_area = creator.main_panel.timeline_panel.drawing_area
-        
+            self.timeline_canvas = creator.main_panel.timeline_panel.timeline_canvas
+
     def zoom_in(self):
-        self.drawing_area.zoom_in()
+        self.timeline_canvas.zoom_in()
 
     def zoom_out(self):
-        self.drawing_area.zoom_out()
+        self.timeline_canvas.zoom_out()
 
-    def vert_zoom_in(self):
-        self.drawing_area.vert_zoom_in()
+    def VertZoomIn(self):
+        self.timeline_canvas.VertZoomIn()
 
-    def vert_zoom_out(self):
-        self.drawing_area.vert_zoom_out()
-        
-    def show_hide_legend(self, checked):
-        self.drawing_area.show_hide_legend(checked)
-        
-    def balloon_visibility_changed(self, checked):
-        self.drawing_area.balloon_visibility_changed(checked)
-        
+    def VertZoomOut(self):
+        self.timeline_canvas.VertZoomOut()
