@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010, 2011  Rickard Lindberg, Roger Lindberg
+# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018  Rickard Lindberg, Roger Lindberg
 #
 # This file is part of Timeline.
 #
@@ -16,24 +16,15 @@
 # along with Timeline.  If not, see <http://www.gnu.org/licenses/>.
 
 
-import wx
-
-
 class SidebarProxy():
-    
+
     def __init__(self, creator):
-        from timelinelib.wxgui.dialogs.mainframe import MainFrame
+        from timelinelib.wxgui.frames.mainframe.mainframe import MainFrame
         if isinstance(creator, MainFrame):
             self.sidebar = creator.main_panel.timeline_panel.sidebar
-        
-    def mouse_over_sidebar(self):
-        pos = wx.GetMousePosition()
-        panel_pos = self.sidebar.ScreenToClient(pos)
-        size = self.sidebar.Size
-        return panel_pos.x <= size.width and panel_pos.y < size.height
-        
+
     def check_categories(self, categories):
         self.sidebar.category_tree.check_categories(categories)
-        
+
     def uncheck_categories(self, categories):
         self.sidebar.category_tree.uncheck_categories(categories)
