@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010, 2011  Rickard Lindberg, Roger Lindberg
+# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018  Rickard Lindberg, Roger Lindberg
 #
 # This file is part of Timeline.
 #
@@ -18,28 +18,30 @@
 
 import wx
 
+from timelinelib.canvas.data.exceptions import TimelineIOError
+from timelinelib.canvas.drawing.utils import darken_color
 from timelinelib.db.utils import safe_locking
-from timelinelib.drawing.utils import darken_color
-from timelinelib.drawing.utils import get_default_font
-from timelinelib.monitoring import monitoring
+from timelinelib import DEBUG_ENABLED
+from timelinelib.monitoring import Monitoring
+from timelinelib.general.observer import Observable
 from timelinelib.repositories.categories import CategoriesFacade
-from timelinelib.utilities.observer import Observable
-from timelinelib.wxgui.components.cattree import add_category
-from timelinelib.wxgui.components.cattree import delete_category
-from timelinelib.wxgui.components.cattree import edit_category
+from timelinelib.wxgui.components.font import Font
+from timelinelib.wxgui.dialogs.editcategory.view import EditCategoryDialog
+import timelinelib.wxgui.utils as gui_utils
 
 
 class CustomCategoryTree(wx.ScrolledWindow):
 
-    def __init__(self, parent, handle_db_error):
-        wx.ScrolledWindow.__init__(self, parent)
+    def __init__(self, parent, name=None, size=(100, 100)):
+        self.monitoring = Monitoring()
+        wx.ScrolledWindow.__init__(self, parent, size=size)
         self.parent = parent
-        self.handle_db_error = handle_db_error
         self._create_context_menu()
         self.Bind(wx.EVT_PAINT, self._on_paint)
         self.Bind(wx.EVT_SIZE, self._on_size)
         self.Bind(wx.EVT_LEFT_DOWN, self._on_left_down)
         self.Bind(wx.EVT_RIGHT_DOWN, self._on_right_down)
+        self.Bind(wx.EVT_LEFT_DCLICK, self._on_left_doubleclick)
         self.model = CustomCategoryTreeModel()
         self.model.listen_for_any(self._redraw)
         self.renderer = CustomCategoryTreeRenderer(self, self.model)
@@ -67,11 +69,16 @@ class CustomCategoryTree(wx.ScrolledWindow):
         return self.db is not None and self.view_properties is not None
 
     def _on_paint(self, event):
-        dc = wx.BufferedPaintDC(self, self.buffer_image, wx.BUFFER_VIRTUAL_AREA)
+        wx.BufferedPaintDC(self, self.buffer_image, wx.BUFFER_VIRTUAL_AREA)
 
     def _on_size(self, event):
         self._size_to_model()
 
+    def _on_left_doubleclick(self, event):
+        def edit_function():
+            self._edit_category()
+        safe_locking(self.parent, edit_function)
+
     def _on_left_down(self, event):
         self.SetFocus()
         self._store_hit_info(event)
@@ -90,17 +97,15 @@ class CustomCategoryTree(wx.ScrolledWindow):
         safe_locking(self.parent, edit_function)
 
     def _on_menu_edit(self, e):
-        hit_category = self.last_hit_info.get_category()
-        if hit_category:
-            edit_category(self, self.db, hit_category, self.handle_db_error)
+        self._edit_category()
 
     def _on_menu_add(self, e):
-        add_category(self, self.db, self.handle_db_error)
+        add_category(self, self.db)
 
     def _on_menu_delete(self, e):
         hit_category = self.last_hit_info.get_category()
         if hit_category:
-            delete_category(self, self.db, hit_category, self.handle_db_error)
+            delete_category(self, self.db, hit_category)
 
     def _on_menu_check_all(self, e):
         self.view_properties.set_categories_visible(
@@ -138,13 +143,18 @@ class CustomCategoryTree(wx.ScrolledWindow):
         self.view_properties.set_categories_visible(
             self.last_hit_info.get_parents(), False)
 
+    def _edit_category(self):
+        hit_category = self.last_hit_info.get_category()
+        if hit_category:
+            edit_category(self, self.db, hit_category)
+
     def _store_hit_info(self, event):
         (x, y) = self.CalcUnscrolledPosition(event.GetX(), event.GetY())
         self.last_hit_info = self.model.hit(x, y)
 
     def _redraw(self):
         self.SetVirtualSize((-1, self.model.ITEM_HEIGHT_PX * len(self.model.items)))
-        self.SetScrollRate(0, self.model.ITEM_HEIGHT_PX/2)
+        self.SetScrollRate(0, self.model.ITEM_HEIGHT_PX / 2)
         self._draw_bitmap()
         self.Refresh()
         self.Update()
@@ -153,19 +163,19 @@ class CustomCategoryTree(wx.ScrolledWindow):
         width, height = self.GetVirtualSizeTuple()
         self.buffer_image = wx.EmptyBitmap(width, height)
         memdc = wx.BufferedDC(None, self.buffer_image)
-        memdc.SetBackground(wx.Brush(self.GetBackgroundColour(), wx.SOLID))
+        memdc.SetBackground(wx.Brush(self.GetBackgroundColour(), wx.PENSTYLE_SOLID))
         memdc.Clear()
         memdc.BeginDrawing()
-        monitoring.timer_start()
+        self.monitoring.timer_start()
         self.renderer.render(memdc)
-        monitoring.timer_end()
-        if monitoring.IS_ENABLED:
+        self.monitoring.timer_end()
+        if DEBUG_ENABLED:
             (width, height) = self.GetSizeTuple()
-            redraw_time = monitoring.timer_elapsed_ms()
-            monitoring.count_category_redraw()
+            redraw_time = self.monitoring.timer_elapsed_ms
+            self.monitoring.count_category_redraw()
             memdc.SetTextForeground((255, 0, 0))
-            memdc.SetFont(get_default_font(10, bold=True))
-            memdc.DrawText("Redraw count: %d" % monitoring.category_redraw_count, 10, height - 35)
+            memdc.SetFont(Font(10, weight=wx.FONTWEIGHT_BOLD))
+            memdc.DrawText("Redraw count: %d" % self.monitoring._category_redraw_count, 10, height - 35)
             memdc.DrawText("Last redraw time: %.3f ms" % redraw_time, 10, height - 20)
         memdc.EndDrawing()
         del memdc
@@ -250,7 +260,7 @@ class CustomCategoryTreeRenderer(object):
         del self.dc
 
     def _render_items(self, items):
-        self.dc.SetFont(wx.SystemSettings_GetFont(wx.SYS_DEFAULT_GUI_FONT))
+        self.dc.SetFont(wx.SystemSettings.GetFont(wx.SYS_DEFAULT_GUI_FONT))
         for item in items:
             self._render_item(item)
 
@@ -262,16 +272,16 @@ class CustomCategoryTreeRenderer(object):
         self._render_color_box(item)
 
     def _render_arrow(self, item):
-        self.dc.SetBrush(wx.Brush(wx.Color(100, 100, 100), wx.SOLID))
-        self.dc.SetPen(wx.Pen(wx.Color(100, 100, 100), 0, wx.SOLID))
-        offset = self.TRIANGLE_SIZE/2
-        center_x = item["x"] + 2*self.INNER_PADDING + offset
-        center_y = item["y"] + self.model.ITEM_HEIGHT_PX/2 - 1
+        self.dc.SetBrush(wx.Brush(wx.Colour(100, 100, 100), wx.PENSTYLE_SOLID))
+        self.dc.SetPen(wx.Pen(wx.Colour(100, 100, 100), 0, wx.PENSTYLE_SOLID))
+        offset = self.TRIANGLE_SIZE / 2
+        center_x = item["x"] + 2 * self.INNER_PADDING + offset
+        center_y = item["y"] + self.model.ITEM_HEIGHT_PX / 2 - 1
         if item["expanded"]:
             open_polygon = [
                 wx.Point(center_x - offset, center_y - offset),
                 wx.Point(center_x + offset, center_y - offset),
-                wx.Point(center_x         , center_y + offset),
+                wx.Point(center_x, center_y + offset),
             ]
             self.dc.DrawPolygon(open_polygon)
         else:
@@ -284,19 +294,19 @@ class CustomCategoryTreeRenderer(object):
 
     def _render_name(self, item):
         x = item["x"] + self.TRIANGLE_SIZE + 4 * self.INNER_PADDING + 20
-        (w, h) = self.dc.GetTextExtent(item["name"])
+        (_, h) = self.dc.GetTextExtent(item["name"])
         if item["actually_visible"]:
             self.dc.SetTextForeground(self.window.GetForegroundColour())
         else:
             self.dc.SetTextForeground((150, 150, 150))
         self.dc.DrawText(item["name"],
                          x + self.INNER_PADDING,
-                         item["y"] + (self.model.ITEM_HEIGHT_PX - h)/2)
+                         item["y"] + (self.model.ITEM_HEIGHT_PX - h) / 2)
 
     def _render_checkbox(self, item):
         (w, h) = (17, 17)
         bouning_rect = wx.Rect(item["x"] + self.model.INDENT_PX,
-                               item["y"] + (self.model.ITEM_HEIGHT_PX - h)/2,
+                               item["y"] + (self.model.ITEM_HEIGHT_PX - h) / 2,
                                w,
                                h)
         if item["visible"]:
@@ -308,12 +318,12 @@ class CustomCategoryTreeRenderer(object):
 
     def _render_color_box(self, item):
         color = item.get("color", None)
-        self.dc.SetBrush(wx.Brush(color, wx.SOLID))
-        self.dc.SetPen(wx.Pen(darken_color(color), 1, wx.SOLID))
+        self.dc.SetBrush(wx.Brush(color, wx.PENSTYLE_SOLID))
+        self.dc.SetPen(wx.Pen(darken_color(color), 1, wx.PENSTYLE_SOLID))
         (w, h) = (16, 16)
         self.dc.DrawRectangle(
             item["x"] + item["width"] - w - self.INNER_PADDING,
-            item["y"] + self.model.ITEM_HEIGHT_PX/2 - h/2,
+            item["y"] + self.model.ITEM_HEIGHT_PX / 2 - h / 2,
             w,
             h)
 
@@ -358,11 +368,11 @@ class CustomCategoryTreeModel(Observable):
             return HitInfo(self.categories, None, False, False)
 
     def toggle_expandedness(self, category):
-        if category.id in self.collapsed_category_ids:
-            self.collapsed_category_ids.remove(category.id)
+        if category.get_id() in self.collapsed_category_ids:
+            self.collapsed_category_ids.remove(category.get_id())
             self._update_items()
         else:
-            self.collapsed_category_ids.append(category.id)
+            self.collapsed_category_ids.append(category.get_id())
             self._update_items()
 
     def _item_at(self, y):
@@ -378,7 +388,7 @@ class CustomCategoryTreeModel(Observable):
 
     def _hits_checkbox(self, x, item):
         return (x > (item["x"] + self.INDENT_PX) and
-                x < (item["x"] + 2*self.INDENT_PX))
+                x < (item["x"] + 2 * self.INDENT_PX))
 
     def _update_items(self):
         self.items = []
@@ -393,18 +403,18 @@ class CustomCategoryTreeModel(Observable):
             return self.categories.get_all()
 
     def _list_to_tree(self, categories, parent=None):
-        top = [category for category in categories if (category.parent == parent)]
-        sorted_top = sorted(top, key=lambda category: category.name)
+        top = [category for category in categories if (category._get_parent() == parent)]
+        sorted_top = sorted(top, key=lambda category: category.get_name())
         return [(category, self._list_to_tree(categories, category)) for
                 category in sorted_top]
 
     def _update_from_tree(self, category_tree, indent_level=0):
         for (category, child_tree) in category_tree:
-            expanded = category.id not in self.collapsed_category_ids
+            expanded = category.get_id() not in self.collapsed_category_ids
             self.items.append({
-                "id": category.id,
-                "name": category.name,
-                "color": category.color,
+                "id": category.get_id(),
+                "name": category.get_name(),
+                "color": category.get_color(),
                 "visible": self._is_category_visible(category),
                 "x": indent_level * self.INDENT_PX,
                 "y": self.y,
@@ -416,7 +426,7 @@ class CustomCategoryTreeModel(Observable):
             })
             self.y += self.ITEM_HEIGHT_PX
             if expanded:
-                self._update_from_tree(child_tree, indent_level+1)
+                self._update_from_tree(child_tree, indent_level + 1)
 
     def _is_category_visible(self, category):
         return self.categories.is_visible(category)
@@ -450,9 +460,35 @@ class HitInfo(object):
 
     def get_parents_for_checked_childs(self):
         return self._categories.get_parents_for_checked_childs()
-        
+
     def is_on_arrow(self):
         return self._is_on_arrow
 
     def is_on_checkbox(self):
         return self._is_on_checkbox
+
+
+def edit_category(parent_ctrl, db, cat):
+    dialog = EditCategoryDialog(parent_ctrl, _("Edit Category"), db, cat)
+    dialog.ShowModal()
+    dialog.Destroy()
+
+
+def add_category(parent_ctrl, db):
+    dialog = EditCategoryDialog(parent_ctrl, _("Add Category"), db, None)
+    dialog.ShowModal()
+    dialog.Destroy()
+
+
+def delete_category(parent_ctrl, db, cat):
+    delete_warning = _("Are you sure you want to "
+                       "delete category '%s'?") % cat.name
+    if cat.parent is None:
+        update_warning = _("Events belonging to '%s' will no longer "
+                           "belong to a category.") % cat.name
+    else:
+        update_warning = _("Events belonging to '%s' will now belong "
+                           "to '%s'.") % (cat.name, cat.parent.name)
+    question = "%s\n\n%s" % (delete_warning, update_warning)
+    if gui_utils._ask_question(question, parent_ctrl) == wx.YES:
+        db.delete_category(cat)
