@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010, 2011  Rickard Lindberg, Roger Lindberg
+# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018  Rickard Lindberg, Roger Lindberg
 #
 # This file is part of Timeline.
 #
@@ -18,15 +18,13 @@
 
 import wx
 
-from timelinelib.db.exceptions import TimelineIOError
-from timelinelib.db.objects.category import sort_categories
+from timelinelib.canvas.data import sort_categories
 
 
 # Border, in pixels, between controls in a window (should always be used when
 # border is needed)
 BORDER = 5
-# Used by dialogs as a return code when a TimelineIOError has been raised
-ID_ERROR = wx.NewId()
+unlock_function = None
 
 
 class WildcardHelper(object):
@@ -67,6 +65,27 @@ class WildcardHelper(object):
                 self.ext_names.append(ext)
 
 
+class PopupTextWindow(wx.PopupTransientWindow):
+
+    def __init__(self, parent, text, color="#D3F4B8", timeout=1200, pos=None):
+        self.timeout = timeout
+        wx.PopupTransientWindow.__init__(self, parent, wx.NO_BORDER)
+        self.SetBackgroundColour(color)
+        st = wx.StaticText(self, wx.ID_ANY, text, pos=(10, 10))
+        sz = st.GetBestSize()
+        self.SetSize((sz.width + 20, sz.height + 20))
+        if pos:
+            self.Position(pos, (-1, -1))
+        self.Popup()
+
+    def ProcessLeftDown(self, evt):
+        return False
+
+    def Popup(self):
+        super(PopupTextWindow, self).Popup()
+        wx.CallLater(self.timeout, self.Dismiss)
+
+
 def category_tree(category_list, parent=None, remove=None):
     """
     Transform flat list of categories to a tree based on parent attribute.
@@ -82,47 +101,13 @@ def category_tree(category_list, parent=None, remove=None):
     children.
     """
     children = [child for child in category_list
-                if (child.parent is parent and child is not remove)]
+                if (child._get_parent() is parent and child is not remove)]
     sorted_children = sort_categories(children)
     tree = [(x, category_tree(category_list, x, remove))
             for x in sorted_children]
     return tree
 
 
-def show_modal(fn_create_dialog, fn_handle_db_error, fn_success=None):
-    """Show a modal dialog using error handling pattern."""
-    try:
-        dialog = fn_create_dialog()
-    except TimelineIOError, e:
-        fn_handle_db_error(e)
-    else:
-        dialog_result = dialog.ShowModal()
-        if dialog_result == ID_ERROR:
-            fn_handle_db_error(dialog.error)
-        elif fn_success:
-            fn_success(dialog)
-        dialog.Destroy()
-
-
-def create_dialog_db_error_handler(dialog):
-    def handler(error):
-        handle_db_error_in_dialog(dialog, error)
-    return handler
-
-
-def handle_db_error_in_dialog(dialog, error):
-    if dialog.IsShown():
-        # Close the dialog and let the code that created it handle the error.
-        # Eventually this error will end up in the main frame (which is the
-        # only object which can handle the error properly).
-        dialog.error = error
-        dialog.EndModal(ID_ERROR)
-    else:
-        # Re-raise the TimelineIOError exception and let the code that created
-        # the dialog handle the error.
-        raise error
-
-
 def _set_focus_and_select(ctrl):
     ctrl.SetFocus()
     if hasattr(ctrl, "SelectAll"):
@@ -139,21 +124,30 @@ def display_warning_message(message, parent=None):
     dial = wx.MessageDialog(parent, message, _("Warning"), wx.OK | wx.ICON_WARNING)
     dial.ShowModal()
 
+
 def display_information_message(caption, message, parent=None):
-    dialog = wx.MessageDialog(parent, message, caption, 
+    dialog = wx.MessageDialog(parent, message, caption,
                               wx.OK | wx.ICON_INFORMATION)
     dialog.ShowModal()
     dialog.Destroy()
 
+
+def display_categories_editor_moved_message(parent):
+    display_information_message(
+        caption=_("Dialog moved"),
+        message=_("This dialog has been removed. Edit categories in the sidebar instead."),
+        parent=parent)
+
+
 def get_user_ack(question, parent=None):
     return wx.MessageBox(question, _("Question"),
-                         wx.YES_NO|wx.CENTRE|wx.NO_DEFAULT, parent) == wx.YES
+                         wx.YES_NO | wx.CENTRE | wx.NO_DEFAULT, parent) == wx.YES
 
 
 def _ask_question(question, parent=None):
     """Ask a yes/no question and return the reply."""
     return wx.MessageBox(question, _("Question"),
-                         wx.YES_NO|wx.CENTRE|wx.NO_DEFAULT, parent)
+                         wx.YES_NO | wx.CENTRE | wx.NO_DEFAULT, parent)
 
 
 def set_wait_cursor(parent):
@@ -164,14 +158,13 @@ def set_default_cursor(parent):
     parent.SetCursor(wx.StockCursor(wx.CURSOR_DEFAULT))
 
 
-def time_picker_for(time_type):
-    from timelinelib.wxgui.components.numtimepicker import NumTimePicker
-    from timelinelib.wxgui.components.gregoriandatetimepicker import GregorianDateTimePicker
-    from timelinelib.time.numtime import NumTimeType
-    from timelinelib.time.gregoriantime import GregorianTimeType
-    if isinstance(time_type, NumTimeType):
-        return NumTimePicker
-    elif isinstance(time_type, GregorianTimeType):
-        return GregorianDateTimePicker
-    else:
-        raise ValueError("Unsupported time type: %s" % time_type)
+def set_focus(parent, name):
+    for child in parent.GetChildren():
+        if child.GetName() == name:
+            child.SetFocus()
+            break
+
+
+def register_unlock_function(function):
+    global unlock_function
+    unlock_function = function
