@@ -494,6 +494,7 @@ def create_bill_from_items(bill_items=None):
 	bill.set_missing_address_from_default()
 
 	return bill
+
 #----------------------------------------------------------------
 def create_invoice_from_bill(parent = None, bill=None, print_it=False, keep_a_copy=True):
 
@@ -620,7 +621,8 @@ def create_invoice_from_bill(parent = None, bill=None, print_it=False, keep_a_co
 			filenames = files2import,
 			document_type = template['instance_type'],
 			review_as_normal = True,
-			reference = bill['invoice_id']
+			reference = bill['invoice_id'],
+			pk_org_unit = gmPraxis.gmCurrentPraxisBranch()['pk_org_unit']
 		)
 		bill['pk_doc'] = doc['pk_doc']
 		bill.save()
@@ -799,6 +801,7 @@ def remove_items_from_bill(parent=None, bill=None):
 		gmBilling.delete_bill(pk_bill = bill['pk_bill'])
 
 	return True
+
 #----------------------------------------------------------------
 def manage_bills(parent=None, patient=None):
 
@@ -1000,7 +1003,7 @@ class cBillEAPnl(wxgBillEAPnl.wxgBillEAPnl, gmEditArea.cGenericEditAreaMixin):
 		if self.data['apply_vat'] is True:
 			tmp = u'%s %%(currency)s%%(total_vat)s %s %s %%(currency)s%%(total_amount_with_vat)s' % (
 				gmTools.u_corresponds_to,
-				gmTools.u_right_arrow,
+				gmTools.u_arrow2right,
 				gmTools.u_sum,
 			)
 			self._TCTRL_value_with_vat.SetValue(tmp % self.data)
@@ -1019,7 +1022,7 @@ class cBillEAPnl(wxgBillEAPnl.wxgBillEAPnl, gmEditArea.cGenericEditAreaMixin):
 		if self._CHBOX_vat_applies.ThreeStateValue == wx.CHK_CHECKED:
 			tmp = u'%s %%(currency)s%%(total_vat)s %s %s %%(currency)s%%(total_amount_with_vat)s' % (
 				gmTools.u_corresponds_to,
-				gmTools.u_right_arrow,
+				gmTools.u_arrow2right,
 				gmTools.u_sum,
 			)
 			self._TCTRL_value_with_vat.SetValue(tmp % self.data)
@@ -1032,7 +1035,7 @@ class cBillEAPnl(wxgBillEAPnl.wxgBillEAPnl, gmEditArea.cGenericEditAreaMixin):
 	def _on_select_address_button_pressed(self, event):
 		adr = gmPersonContactWidgets.select_address (
 			missing = _('billing'),
-			person = gmPerson.cIdentity(aPK_obj = self.data['pk_patient'])
+			person = gmPerson.cPerson(aPK_obj = self.data['pk_patient'])
 		)
 		if adr is None:
 			gmGuiHelpers.gm_show_info (
@@ -1139,10 +1142,10 @@ class cPersonBillItemsManagerPnl(gmListWidgets.cGenericListManagerPnl):
 
 		gmListWidgets.cGenericListManagerPnl.__init__(self, *args, **kwargs)
 
+		self.refresh_callback = self.refresh
 		self.new_callback = self._add_item
 		self.edit_callback = self._edit_item
 		self.delete_callback = self._del_item
-		self.refresh_callback = self.refresh
 
 		self.__show_non_invoiced_only = True
 
@@ -1571,6 +1574,5 @@ if __name__ == '__main__':
 
 	#----------------------------------------
 	app = wx.PyWidgetTester(size = (600, 600))
-	#app.SetWidget(cATCPhraseWheel, -1)
-	#app.SetWidget(cSubstancePhraseWheel, -1)
+	#app.SetWidget(cXxxPhraseWheel, -1)
 	app.MainLoop()
