@@ -21,6 +21,8 @@ from Gnumed.pycommon import gmNetworkTools
 from Gnumed.pycommon import gmTools
 from Gnumed.pycommon import gmDispatcher
 from Gnumed.pycommon import gmCfg2
+from Gnumed.pycommon import gmWorkerThread
+from Gnumed.pycommon import gmPG2
 from Gnumed.business import gmPraxis
 from Gnumed.wxpython import gmGuiHelpers
 from Gnumed.wxpython import gmListWidgets
@@ -30,17 +32,15 @@ _log = logging.getLogger('gm.ui')
 _log.info(__version__)
 
 #==============================================================================
-def check_for_updates():
+def _get_update_status():
 
 	dbcfg = gmCfg.cCfgSQL()
-
 	url = dbcfg.get2 (
 		option = u'horstspace.update.url',
 		workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 		bias = 'workplace',
 		default = u'http://www.gnumed.de/downloads/gnumed-versions.txt'
 	)
-
 	consider_latest_branch = bool(dbcfg.get2 (
 		option = u'horstspace.update.consider_latest_branch',
 		workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
@@ -49,15 +49,21 @@ def check_for_updates():
 	))
 
 	_cfg = gmCfg2.gmCfgData()
-
-	found, msg = gmNetworkTools.check_for_update (
+	update_found, msg = gmNetworkTools.check_for_update (
 		url = url,
 		current_branch = _cfg.get(option = 'client_branch'),
 		current_version = _cfg.get(option = 'client_version'),
 		consider_latest_branch = consider_latest_branch
 	)
 
-	if found is False:
+	return update_found, msg
+
+#------------------------------------------------------------------------------
+def _signal_update_status(status):
+
+	update_found, msg = status
+	if update_found is False:
+		_cfg = gmCfg2.gmCfgData()
 		gmDispatcher.send(signal = 'statustext', msg = _('Your client (%s) is up to date.') % _cfg.get(option = 'client_version'))
 		return
 
@@ -65,6 +71,26 @@ def check_for_updates():
 		msg,
 		_('Checking for client updates')
 	)
+
+#------------------------------------------------------------------------------
+def _async_signal_update_status(status):
+	gmPG2.discard_pooled_connection()
+	wx.CallAfter(_signal_update_status, status)
+
+#------------------------------------------------------------------------------
+def check_for_updates(async=False):
+
+	if async:
+		gmWorkerThread.execute_in_worker_thread (
+			payload_function = _get_update_status,
+			payload_kwargs = None,
+			completion_callback = _async_signal_update_status,
+			worker_name = u'UpdChk'
+		)
+		return
+
+	_signal_update_status(_get_update_status())
+
 #================================================================
 def list_configuration(parent=None):
 
@@ -151,6 +177,7 @@ def list_configuration(parent=None):
 		ignore_OK_button = True,
 		list_tooltip_callback = tooltip
 	)
+
 #================================================================
 def configure_string_from_list_option(parent=None, message=None, option=None, bias='user', default_value=u'', choices=None, columns=None, data=None, caption=None):
 
@@ -204,6 +231,49 @@ def configure_string_from_list_option(parent=None, message=None, option=None, bi
 	)
 
 	return
+
+#================================================================
+def configure_list_from_list_option(parent=None, message=None, option=None, bias='user', default_value=None, choices=None, columns=None, data=None, caption=None, picks=None):
+
+	if default_value is None:
+		default_value = []
+
+	dbcfg = gmCfg.cCfgSQL()
+
+	current_value = dbcfg.get2 (
+		option = option,
+		workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
+		bias = bias,
+		default = default_value
+	)
+
+	if parent is None:
+		parent = wx.GetApp().GetTopWindow()
+
+	if caption is None:
+		caption = _('Configuration')
+
+	# setup item picker
+	picker = gmListWidgets.cItemPickerDlg(parent, -1, msg = message)
+	picker.set_columns(columns)
+	picker.set_choices(choices)
+	picker.set_picks(picks)
+	result = picker.ShowModal()
+	if result == wx.ID_CANCEL:
+		picker.Destroy()
+		return
+
+	picks = picker.get_picks()
+	picker.Destroy()
+
+	dbcfg.set (
+		workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
+		option = option,
+		value = picks
+	)
+
+	return
+
 #================================================================
 def configure_string_option(parent=None, message=None, option=None, bias=u'user', default_value=u'', validator=None):
 
@@ -259,6 +329,7 @@ def configure_string_option(parent=None, message=None, option=None, bias=u'user'
 	)
 
 	return user_val
+
 #================================================================
 def configure_boolean_option(parent=None, question=None, option=None, button_tooltips=None):
 
@@ -302,6 +373,7 @@ def configure_boolean_option(parent=None, question=None, option=None, button_too
 		)
 
 	return
+
 #================================================================
 if __name__ == '__main__':
 
@@ -309,8 +381,10 @@ if __name__ == '__main__':
 	gmI18N.activate_locale()
 	gmI18N.install_domain()
 
-	if (len(sys.argv) > 1):
-		if sys.argv[1] == 'test':
-			check_for_updates()
+	if len(sys.argv) < 2:
+		sys.exit()
 
-#================================================================
+	if sys.argv[1] != 'test':
+		sys.exit()
+
+	check_for_updates()
