@@ -46,6 +46,8 @@ from Gnumed.wxpython import gmVaccWidgets
 from Gnumed.wxpython import gmFamilyHistoryWidgets
 from Gnumed.wxpython import gmFormWidgets
 from Gnumed.wxpython import gmTimer
+from Gnumed.wxpython import gmHospitalStayWidgets
+from Gnumed.wxpython import gmProcedureWidgets
 
 
 _log = logging.getLogger('gm.ui')
@@ -256,6 +258,7 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 
 		wx.EndBusyCursor()
 		return True
+
 	#--------------------------------------------------------
 	def __populate_root_node(self):
 
@@ -353,7 +356,8 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 			if len(epis) > 0:
 				self.__img_display.refresh (
 					document_folder = doc_folder,
-					episodes = [ epi['pk_episode'] for epi in epis ]
+					episodes = [ epi['pk_episode'] for epi in epis ],
+					async = True
 				)
 			self.__soap_display.SetFont(font)
 			self.__soap_display.WriteText(txt)
@@ -461,7 +465,7 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 		# root node == EMR level
 		self.__cb__enable_display_mode_selection(True)
 		if self.__soap_display_mode == u'details':
-			emr = self.__pat.get_emr()
+			emr = self.__pat.emr
 			txt = emr.format_summary()
 		else:
 			txt = self.__pat.emr.format_as_journal(left_margin = 1, patient = self.__pat)
@@ -604,12 +608,10 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 
 	#--------------------------------------------------------
 	def __handle_issue_context(self, pos=wx.DefaultPosition):
-#		self.__issue_context_popup.SetTitle(_('Episode %s') % episode['description'])
 		self.PopupMenu(self.__issue_context_popup, pos)
 
 	#--------------------------------------------------------
 	def __handle_episode_context(self, pos=wx.DefaultPosition):
-#		self.__epi_context_popup.SetTitle(_('Episode %s') % self.__curr_node_data['description'])
 		self.PopupMenu(self.__epi_context_popup, pos)
 
 	#--------------------------------------------------------
@@ -712,6 +714,7 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 			encounters = [encounter['pk_encounter']],
 			episodes = [episode['pk_episode']]
 		)
+
 	#--------------------------------------------------------
 	def __edit_progress_notes(self, event):
 		encounter = self.GetPyData(self.__curr_node)
@@ -723,11 +726,13 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 			encounters = [encounter['pk_encounter']],
 			episodes = [episode['pk_episode']]
 		)
+
 	#--------------------------------------------------------
 	def __edit_encounter_details(self, event):
 		node_data = self.GetPyData(self.__curr_node)
 		gmEncounterWidgets.edit_encounter(parent = self, encounter = node_data)
 		self.__populate_tree()
+
 	#--------------------------------------------------------
 	def __relink_encounter_data2episode(self, event):
 
@@ -746,6 +751,7 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 
 		if result == wx.ID_YES:
 			self.__populate_tree()
+
 	#--------------------------------------------------------
 	# issue level
 	#--------------------------------------------------------
@@ -804,9 +810,13 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 		self.SetItemHasChildren(issue_node, True)
 
 		for episode in episodes:
-			episode_node =  self.AppendItem(issue_node, episode['description'])
+			range_str, range_str_verb, duration_str = episode.formatted_clinical_duration
+			episode_node =  self.AppendItem(issue_node, u'%s (%s)' % (
+				episode['description'],
+				range_str
+			))
 			self.SetItemPyData(episode_node, episode)
-			# fake it so we can expand it
+			# assume children so we can try to expand it
 			self.SetItemHasChildren(episode_node, True)
 
 		self.SortChildren(issue_node)
@@ -823,11 +833,15 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 		self.SetItemHasChildren(fake_issue_node, True)
 
 		for episode in episodes:
-			episode_node =  self.AppendItem(fake_issue_node, episode['description'])
+			range_str, range_str_verb, duration_str = episode.formatted_clinical_duration
+			episode_node =  self.AppendItem(fake_issue_node, u'%s (%s)' % (
+				episode['description'],
+				range_str
+			))
 			self.SetItemPyData(episode_node, episode)
 			if episode['episode_open']:
 				self.SetItemBold(fake_issue_node, True)
-			# fake it so we can expand it
+			# assume children so we can try to expand it
 			self.SetItemHasChildren(episode_node, True)
 
 		self.SortChildren(fake_issue_node)
@@ -863,7 +877,7 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 
 	#--------------------------------------------------------
 	def __manage_procedures(self, event):
-		gmEMRStructWidgets.manage_performed_procedures(parent = self)
+		gmProcedureWidgets.manage_performed_procedures(parent = self)
 
 	#--------------------------------------------------------
 	def __manage_family_history(self, event):
@@ -871,7 +885,7 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 
 	#--------------------------------------------------------
 	def __manage_hospital_stays(self, event):
-		gmEMRStructWidgets.manage_hospital_stays(parent = self)
+		gmHospitalStayWidgets.manage_hospital_stays(parent = self)
 
 	#--------------------------------------------------------
 	def __manage_occupation(self, event):
@@ -985,10 +999,12 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 	def _on_episode_mod_db(self, *args, **kwargs):
 		self.__expanded_nodes = self.ExpansionState
 		self.__populate_tree()
+
 	#--------------------------------------------------------
 	def _on_issue_mod_db(self, *args, **kwargs):
 		self.__expanded_nodes = self.ExpansionState
 		self.__populate_tree()
+
 	#--------------------------------------------------------
 	def _on_tree_item_expanding(self, event):
 		event.Skip()
@@ -1015,12 +1031,14 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 
 		# encounter nodes do not need expanding
 		#if isinstance(node_data, gmEMRStructItems.cEncounter):
+
 	#--------------------------------------------------------
 	def _on_tree_item_selected(self, event):
 		sel_item = event.GetItem()
 		self.__curr_node = sel_item
 		self.__update_text_for_selected_node()
 		return True
+
 #	#--------------------------------------------------------
 #	def _on_mouse_motion(self, event):
 #
@@ -1170,6 +1188,7 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 #otherwise a test would be needed
 #if widgetXY.GetToolTip():
 #    widgetXY.GetToolTip().Enable(False)
+
 	#--------------------------------------------------------
 	def _on_tree_item_right_clicked(self, event):
 		"""Right button clicked: display the popup for the tree"""
@@ -1194,6 +1213,7 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 		else:
 			print "error: unknown node type, no popup menu"
 		event.Skip()
+
 	#--------------------------------------------------------
 	def OnCompareItems (self, node1=None, node2=None):
 		"""Used in sorting items.
@@ -1235,15 +1255,20 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 				return -1
 			return 1
 
-		# episodes: chronologically
+		# episodes: open, then reverse chronologically
 		if isinstance(item1, gmEMRStructItems.cEpisode):
-			start1 = item1.best_guess_start_date
-			start2 = item2.best_guess_start_date
+			# open episodes first
+			if item1['episode_open']:
+				return -1
+			if item2['episode_open']:
+				return 1
+			start1 = item1.best_guess_clinical_start_date
+			start2 = item2.best_guess_clinical_start_date
 			if start1 == start2:
 				return 0
 			if start1 < start2:
-				return -1
-			return 1
+				return 1
+			return -1
 
 		# issues: alpha by grouping, no grouping at the bottom
 		if isinstance(item1, gmEMRStructItems.cHealthIssue):
@@ -1286,6 +1311,7 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 		_log.error('item2: %s', type(item2))
 
 		return 0
+
 	#--------------------------------------------------------
 	# properties
 	#--------------------------------------------------------
@@ -1356,6 +1382,7 @@ class cSplittedEMRTreeBrowserPnl(wxgSplittedEMRTreeBrowserPnl.wxgSplittedEMRTree
 		gmDispatcher.connect(signal = u'pre_patient_unselection', receiver = self._on_pre_patient_unselection)
 		gmDispatcher.connect(signal = u'post_patient_selection', receiver = self._on_post_patient_selection)
 		return True
+
 	#--------------------------------------------------------
 	def _get_editing(self):
 		return self.__editing
@@ -1376,6 +1403,7 @@ class cSplittedEMRTreeBrowserPnl(wxgSplittedEMRTreeBrowserPnl.wxgSplittedEMRTree
 		self._PNL_right_side.GetSizer().Layout()
 
 	editing = property(_get_editing, _set_editing)
+
 	#--------------------------------------------------------
 	# event handler
 	#--------------------------------------------------------
@@ -1383,24 +1411,30 @@ class cSplittedEMRTreeBrowserPnl(wxgSplittedEMRTreeBrowserPnl.wxgSplittedEMRTree
 		self._pnl_emr_tree._emr_tree.patient = None
 		self._PNL_edit.patient = None
 		return True
+
 	#--------------------------------------------------------
 	def _on_post_patient_selection(self):
 		if self.GetParent().GetCurrentPage() != self:
 			return True
 		self.repopulate_ui()
 		return True
+
 	#--------------------------------------------------------
 	def _on_show_details_selected(self, event):
 		self._pnl_emr_tree._emr_tree.details_display_mode = u'details'
+
 	#--------------------------------------------------------
 	def _on_show_journal_selected(self, event):
 		self._pnl_emr_tree._emr_tree.details_display_mode = u'journal'
+
 	#--------------------------------------------------------
 	def _on_show_revisions_selected(self, event):
 		self._pnl_emr_tree._emr_tree.details_display_mode = u'revisions'
+
 	#--------------------------------------------------------
 	def _on_switch_browse_edit_button_pressed(self, event):
 		self.editing = not self.__editing
+
 	#--------------------------------------------------------
 	# external API
 	#--------------------------------------------------------
@@ -1409,8 +1443,10 @@ class cSplittedEMRTreeBrowserPnl(wxgSplittedEMRTreeBrowserPnl.wxgSplittedEMRTree
 		pat = gmPerson.gmCurrentPatient()
 		self._pnl_emr_tree._emr_tree.patient = pat
 		self._PNL_edit.patient = pat
-		self._splitter_browser.SetSashPosition(self._splitter_browser.GetSizeTuple()[0]/3, True)
+		self._splitter_browser.SetSashPosition(self._splitter_browser.GetSizeTuple()[0] // 3, True)
+
 		return True
+
 	#--------------------------------------------------------
 	def enable_display_mode_selection(self, enable):
 		if self.editing:
@@ -1423,9 +1459,11 @@ class cSplittedEMRTreeBrowserPnl(wxgSplittedEMRTreeBrowserPnl.wxgSplittedEMRTree
 		self._RBTN_details.Enable(False)
 		self._RBTN_journal.Enable(False)
 		self._RBTN_revisions.Enable(False)
+
 	#--------------------------------------------------------
 	def _add_soap_editor(self, problem=None, allow_same_problem=False):
 		self._PNL_edit._NB_soap_editors.add_editor(problem = problem, allow_same_problem = allow_same_problem)
+
 	#--------------------------------------------------------
 	def _select_edit_mode(self, edit=True):
 		self.editing = edit
@@ -1447,9 +1485,9 @@ class cEMRJournalPluginPnl(wxgEMRJournalPluginPnl.wxgEMRJournalPluginPnl):
 		self._TCTRL_journal.SetValue(u'')
 		exporter = gmPatientExporter.cEMRJournalExporter()
 		if self._RBTN_by_encounter.GetValue():
-			fname = exporter.export_to_file_by_encounter(patient = gmPerson.gmCurrentPatient())
+			fname = exporter.save_to_file_by_encounter(patient = gmPerson.gmCurrentPatient())
 		else:
-			fname = exporter.export_to_file_by_mod_time(patient = gmPerson.gmCurrentPatient())
+			fname = exporter.save_to_file_by_mod_time(patient = gmPerson.gmCurrentPatient())
 
 		f = io.open(fname, mode = 'rt', encoding = 'utf8', errors = 'replace')
 		for line in f:
@@ -1516,17 +1554,17 @@ class cEMRListJournalPluginPnl(wxgEMRListJournalPluginPnl.wxgEMRListJournalPlugi
 		self._TCTRL_details.SetValue(u'')
 
 		if self._RBTN_by_encounter.Value:		# (... is True:)
-			order_by = u'c_vej.encounter_started, c_vej.pk_episode, c_vej.src_table, scr, c_vej.modified_when'
-						#, c_vej.clin_when (should not make a relevant difference)
+			order_by = u'encounter_started, pk_episode, src_table, scr, modified_when'
+						#, clin_when (should not make a relevant difference)
 			date_col_header = _('Encounter')
 			date_fields = ['encounter_started', 'modified_when']
 		elif self._RBTN_by_last_modified.Value:	# (... is True:)
-			order_by = u'c_vej.modified_when, c_vej.pk_episode, c_vej.src_table, scr'
-						#, c_vej.clin_when (should not make a relevant difference)
+			order_by = u'modified_when, pk_episode, src_table, scr'
+						#, clin_when (should not make a relevant difference)
 			date_col_header = _('Modified')
 			date_fields = ['modified_when']
 		elif self._RBTN_by_item_time.Value:		# (... is True:)
-			order_by = u'c_vej.clin_when, c_vej.pk_episode, c_vej.src_table, scr, c_vej.modified_when'
+			order_by = u'clin_when, pk_episode, src_table, scr, modified_when'
 			date_col_header = _('Clinical time')
 			date_fields = ['clin_when', 'modified_when']
 		else:
@@ -1556,7 +1594,9 @@ class cEMRListJournalPluginPnl(wxgEMRListJournalPluginPnl.wxgEMRListJournalPlugi
 				date2show = entry_date
 				prev_date = entry_date
 			lines = entry['narrative'].strip().split(u'\n')
-			entry_line = lines[0].rstrip()
+			line_0 = lines[0].rstrip()				# assumes there's at least one line ...
+			delim = gmTools.u_box_horiz_light_3dashes * 10
+			entry_line = u'%s %s' % (line_0, delim)
 			items.append([date2show, soap_cat, entry_line, who])
 			try:
 				self.__data[entry['src_table']]
