@@ -47,7 +47,6 @@ from Gnumed.wxpython import gmPhraseWheel
 from Gnumed.wxpython import gmGuiHelpers
 from Gnumed.wxpython import gmListWidgets
 from Gnumed.wxpython import gmEditArea
-from Gnumed.wxpython import gmOrganizationWidgets
 
 
 _log = logging.getLogger('gm.ui')
@@ -71,746 +70,6 @@ def emr_access_spinner(time2spin=0):
 		time.sleep(sleep_time)
 		rounds += 1
 
-#================================================================
-# performed procedure related widgets/functions
-#----------------------------------------------------------------
-def manage_performed_procedures(parent=None):
-
-	pat = gmPerson.gmCurrentPatient()
-	emr = pat.get_emr()
-
-	if parent is None:
-		parent = wx.GetApp().GetTopWindow()
-
-	#-----------------------------------------
-	def get_tooltip(procedure=None):
-		if procedure is None:
-			return None
-		return procedure.format (
-			left_margin = 1,
-			include_episode = False,
-			include_codes = False,
-			include_address = True,
-			include_comm = True
-		)
-
-	#-----------------------------------------
-	def edit(procedure=None):
-		return edit_procedure(parent = parent, procedure = procedure)
-
-	#-----------------------------------------
-	def delete(procedure=None):
-		if gmEMRStructItems.delete_performed_procedure(procedure = procedure['pk_procedure']):
-			return True
-
-		gmDispatcher.send (
-			signal = u'statustext',
-			msg = _('Cannot delete performed procedure.'),
-			beep = True
-		)
-		return False
-
-	#-----------------------------------------
-	def refresh(lctrl):
-		procs = emr.get_performed_procedures()
-		items = [
-			[
-				u'%s%s' % (
-					p['clin_when'].strftime('%Y-%m-%d'),
-					gmTools.bool2subst (
-						p['is_ongoing'],
-						_(' (ongoing)'),
-						gmTools.coalesce (
-							initial = p['clin_end'],
-							instead = u'',
-							template_initial = u' - %s',
-							function_initial = ('strftime', u'%Y-%m-%d')
-						)
-					)
-				),
-				p['performed_procedure'],
-				u'%s @ %s' % (p['unit'], p['organization']),
-				p['episode']
-			] for p in procs
-		]
-		lctrl.set_string_items(items = items)
-		lctrl.set_data(data = procs)
-
-	#-----------------------------------------
-	gmListWidgets.get_choices_from_list (
-		parent = parent,
-		msg = _('\nSelect the procedure you want to edit !\n'),
-		caption = _('Editing performed procedures ...'),
-		columns = [_('When'), _('Procedure'), _('Where'), _('Episode')],
-		single_selection = True,
-		edit_callback = edit,
-		new_callback = edit,
-		delete_callback = delete,
-		refresh_callback = refresh,
-		list_tooltip_callback = get_tooltip
-	)
-
-#----------------------------------------------------------------
-def edit_procedure(parent=None, procedure=None):
-	ea = cProcedureEAPnl(parent = parent, id = -1)
-	ea.data = procedure
-	ea.mode = gmTools.coalesce(procedure, 'new', 'edit')
-	dlg = gmEditArea.cGenericEditAreaDlg2(parent = parent, id = -1, edit_area = ea, single_entry = True)
-	dlg.SetTitle(gmTools.coalesce(procedure, _('Adding a procedure'), _('Editing a procedure')))
-	if dlg.ShowModal() == wx.ID_OK:
-		dlg.Destroy()
-		return True
-	dlg.Destroy()
-	return False
-
-#----------------------------------------------------------------
-from Gnumed.wxGladeWidgets import wxgProcedureEAPnl
-
-class cProcedureEAPnl(wxgProcedureEAPnl.wxgProcedureEAPnl, gmEditArea.cGenericEditAreaMixin):
-
-	def __init__(self, *args, **kwargs):
-		wxgProcedureEAPnl.wxgProcedureEAPnl.__init__(self, *args, **kwargs)
-		gmEditArea.cGenericEditAreaMixin.__init__(self)
-
-		self.mode = 'new'
-		self.data = None
-
-		self.__init_ui()
-	#----------------------------------------------------------------
-	def __init_ui(self):
-		self._PRW_hospital_stay.add_callback_on_lose_focus(callback = self._on_hospital_stay_lost_focus)
-		self._PRW_hospital_stay.set_context(context = 'pat', val = gmPerson.gmCurrentPatient().ID)
-		self._PRW_location.add_callback_on_lose_focus(callback = self._on_location_lost_focus)
-		self._DPRW_date.add_callback_on_lose_focus(callback = self._on_start_lost_focus)
-		self._DPRW_end.add_callback_on_lose_focus(callback = self._on_end_lost_focus)
-
-		# procedure
-		mp = gmMatchProvider.cMatchProvider_SQL2 (
-			queries = [
-u"""
-select distinct on (narrative) narrative, narrative
-from clin.procedure
-where narrative %(fragment_condition)s
-order by narrative
-limit 25
-"""			]
-		)
-		mp.setThresholds(2, 4, 6)
-		self._PRW_procedure.matcher = mp
-	#----------------------------------------------------------------
-	def _on_hospital_stay_lost_focus(self):
-		stay = self._PRW_hospital_stay.GetData()
-		if stay is None:
-			self._PRW_hospital_stay.SetText()
-			self._PRW_location.Enable(True)
-			self._PRW_episode.Enable(True)
-			self._LBL_hospital_details.SetLabel(u'')
-		else:
-			self._PRW_location.SetText()
-			self._PRW_location.Enable(False)
-			self._PRW_episode.SetText()
-			self._PRW_episode.Enable(False)
-			self._LBL_hospital_details.SetLabel(gmEMRStructItems.cHospitalStay(aPK_obj = stay).format())
-	#----------------------------------------------------------------
-	def _on_location_lost_focus(self):
-		loc = self._PRW_location.GetData()
-		if loc is None:
-			self._PRW_hospital_stay.Enable(True)
-			self._PRW_episode.Enable(False)
-		else:
-			self._PRW_hospital_stay.SetText()
-			self._PRW_hospital_stay.Enable(False)
-			self._PRW_episode.Enable(True)
-	#----------------------------------------------------------------
-	def _on_start_lost_focus(self):
-		if not self._DPRW_date.is_valid_timestamp():
-			return
-		end = self._DPRW_end.GetData()
-		if end is None:
-			return
-		end = end.get_pydt()
-		start = self._DPRW_date.GetData().get_pydt()
-		if start < end:
-			return
-		self._DPRW_date.display_as_valid(False)
-	#----------------------------------------------------------------
-	def _on_end_lost_focus(self):
-		end = self._DPRW_end.GetData()
-		if end is None:
-			self._CHBOX_ongoing.Enable(True)
-			self._DPRW_end.display_as_valid(True)
-		else:
-			self._CHBOX_ongoing.Enable(False)
-			end = end.get_pydt()
-			now = gmDateTime.pydt_now_here()
-			if end > now:
-				self._CHBOX_ongoing.SetValue(True)
-			else:
-				self._CHBOX_ongoing.SetValue(False)
-			start = self._DPRW_date.GetData()
-			if start is None:
-				self._DPRW_end.display_as_valid(True)
-			else:
-				start = start.get_pydt()
-				if end > start:
-					self._DPRW_end.display_as_valid(True)
-				else:
-					self._DPRW_end.display_as_valid(False)
-	#----------------------------------------------------------------
-	# generic Edit Area mixin API
-	#----------------------------------------------------------------
-	def _valid_for_save(self):
-
-		has_errors = False
-
-		if not self._DPRW_date.is_valid_timestamp():
-			self._DPRW_date.display_as_valid(False)
-			has_errors = True
-		else:
-			self._DPRW_date.display_as_valid(True)
-
-		start = self._DPRW_date.GetData()
-		end = self._DPRW_end.GetData()
-		self._DPRW_end.display_as_valid(True)
-		if end is not None:
-			end = end.get_pydt()
-			if start is not None:
-				start = start.get_pydt()
-				if end < start:
-					has_errors = True
-					self._DPRW_end.display_as_valid(False)
-			if self._CHBOX_ongoing.IsChecked():
-				now = gmDateTime.pydt_now_here()
-				if end < now:
-					has_errors = True
-					self._DPRW_end.display_as_valid(False)
-
-		if self._PRW_hospital_stay.GetData() is None:
-			if self._PRW_episode.GetValue().strip() == u'':
-				self._PRW_episode.display_as_valid(False)
-				has_errors = True
-			else:
-				self._PRW_episode.display_as_valid(True)
-		else:
-			self._PRW_episode.display_as_valid(True)
-
-		if (self._PRW_procedure.GetValue() is None) or (self._PRW_procedure.GetValue().strip() == u''):
-			self._PRW_procedure.display_as_valid(False)
-			has_errors = True
-		else:
-			self._PRW_procedure.display_as_valid(True)
-
-		invalid_location = (
-			(self._PRW_hospital_stay.GetData() is None) and (self._PRW_location.GetData() is None)
-				or
-			(self._PRW_hospital_stay.GetData() is not None) and (self._PRW_location.GetData() is not None)
-		)
-		if invalid_location:
-			self._PRW_hospital_stay.display_as_valid(False)
-			self._PRW_location.display_as_valid(False)
-			has_errors = True
-		else:
-			self._PRW_hospital_stay.display_as_valid(True)
-			self._PRW_location.display_as_valid(True)
-
-		gmDispatcher.send(signal = 'statustext', msg = _('Cannot save procedure.'), beep = True)
-
-		return (has_errors is False)
-	#----------------------------------------------------------------
-	def _save_as_new(self):
-
-		pat = gmPerson.gmCurrentPatient()
-		emr = pat.get_emr()
-
-		stay = self._PRW_hospital_stay.GetData()
-		if stay is None:
-			epi = self._PRW_episode.GetData(can_create = True)
-		else:
-			epi = gmEMRStructItems.cHospitalStay(aPK_obj = stay)['pk_episode']
-
-		proc = emr.add_performed_procedure (
-			episode = epi,
-			location = self._PRW_location.GetData(),
-			hospital_stay = stay,
-			procedure = self._PRW_procedure.GetValue().strip()
-		)
-
-		proc['clin_when'] = self._DPRW_date.GetData().get_pydt()
-		if self._DPRW_end.GetData() is None:
-			proc['clin_end'] = None
-		else:
-			proc['clin_end'] = self._DPRW_end.GetData().get_pydt()
-		proc['is_ongoing'] = self._CHBOX_ongoing.IsChecked()
-		proc.save()
-
-		proc.generic_codes = [ c['data'] for c in self._PRW_codes.GetData() ]
-
-		self.data = proc
-
-		return True
-	#----------------------------------------------------------------
-	def _save_as_update(self):
-		self.data['clin_when'] = self._DPRW_date.GetData().get_pydt()
-		self.data['is_ongoing'] = self._CHBOX_ongoing.IsChecked()
-		self.data['pk_org_unit'] = self._PRW_location.GetData()
-		self.data['pk_hospital_stay'] = self._PRW_hospital_stay.GetData()
-		self.data['performed_procedure'] = self._PRW_procedure.GetValue().strip()
-		if self._DPRW_end.GetData() is None:
-			self.data['clin_end'] = None
-		else:
-			self.data['clin_end'] = self._DPRW_end.GetData().get_pydt()
-		if self.data['pk_hospital_stay'] is None:
-			self.data['pk_episode'] = self._PRW_episode.GetData()
-		else:
-			self.data['pk_episode'] = gmEMRStructItems.cHospitalStay(aPK_obj = self._PRW_hospital_stay.GetData())['pk_episode']
-		self.data.save()
-
-		self.data.generic_codes = [ c['data'] for c in self._PRW_codes.GetData() ]
-
-		return True
-	#----------------------------------------------------------------
-	def _refresh_as_new(self):
-		self._DPRW_date.SetText()
-		self._DPRW_end.SetText()
-		self._CHBOX_ongoing.SetValue(False)
-		self._CHBOX_ongoing.Enable(True)
-		self._PRW_hospital_stay.SetText()
-		self._LBL_hospital_details.SetLabel(u'')
-		self._PRW_location.SetText()
-		self._PRW_episode.SetText()
-		self._PRW_procedure.SetText()
-		self._PRW_codes.SetText()
-
-		self._PRW_procedure.SetFocus()
-	#----------------------------------------------------------------
-	def _refresh_from_existing(self):
-		self._DPRW_date.SetData(data = self.data['clin_when'])
-		if self.data['clin_end'] is None:
-			self._DPRW_end.SetText()
-			self._CHBOX_ongoing.Enable(True)
-			self._CHBOX_ongoing.SetValue(self.data['is_ongoing'])
-		else:
-			self._DPRW_end.SetData(data = self.data['clin_end'])
-			self._CHBOX_ongoing.Enable(False)
-			now = gmDateTime.pydt_now_here()
-			if self.data['clin_end'] > now:
-				self._CHBOX_ongoing.SetValue(True)
-			else:
-				self._CHBOX_ongoing.SetValue(False)
-		self._PRW_episode.SetText(value = self.data['episode'], data = self.data['pk_episode'])
-		self._PRW_procedure.SetText(value = self.data['performed_procedure'], data = self.data['performed_procedure'])
-
-		if self.data['pk_hospital_stay'] is None:
-			self._PRW_hospital_stay.SetText()
-			self._PRW_hospital_stay.Enable(False)
-			self._LBL_hospital_details.SetLabel(u'')
-			self._PRW_location.SetText(value = u'%s @ %s' % (self.data['unit'], self.data['organization']), data = self.data['pk_org_unit'])
-			self._PRW_location.Enable(True)
-			self._PRW_episode.Enable(True)
-		else:
-			self._PRW_hospital_stay.SetText(value = u'%s @ %s' % (self.data['unit'], self.data['organization']), data = self.data['pk_hospital_stay'])
-			self._PRW_hospital_stay.Enable(True)
-			self._LBL_hospital_details.SetLabel(gmEMRStructItems.cHospitalStay(aPK_obj = self.data['pk_hospital_stay']).format())
-			self._PRW_location.SetText()
-			self._PRW_location.Enable(False)
-			self._PRW_episode.Enable(False)
-
-		val, data = self._PRW_codes.generic_linked_codes2item_dict(self.data.generic_codes)
-		self._PRW_codes.SetText(val, data)
-
-		self._PRW_procedure.SetFocus()
-	#----------------------------------------------------------------
-	def _refresh_as_new_from_existing(self):
-		self._refresh_as_new()
-
-		self._PRW_episode.SetText(value = self.data['episode'], data = self.data['pk_episode'])
-
-		if self.data['pk_hospital_stay'] is None:
-			self._PRW_hospital_stay.SetText()
-			self._PRW_hospital_stay.Enable(False)
-			self._LBL_hospital_details.SetLabel(u'')
-			self._PRW_location.SetText(value = u'%s @ %s' % (self.data['unit'], self.data['organization']), data = self.data['pk_org_unit'])
-			self._PRW_location.Enable(True)
-			self._PRW_episode.Enable(True)
-		else:
-			self._PRW_hospital_stay.SetText(value = u'%s @ %s' % (self.data['unit'], self.data['organization']), data = self.data['pk_hospital_stay'])
-			self._PRW_hospital_stay.Enable(True)
-			self._LBL_hospital_details.SetLabel(gmEMRStructItems.cHospitalStay(aPK_obj = self.data['pk_hospital_stay']).format())
-			self._PRW_location.SetText()
-			self._PRW_location.Enable(False)
-			self._PRW_episode.Enable(False)
-
-		self._PRW_procedure.SetFocus()
-	#----------------------------------------------------------------
-	# event handlers
-	#----------------------------------------------------------------
-	def _on_add_hospital_stay_button_pressed(self, evt):
-		# FIXME: this would benefit from setting the created stay
-		edit_hospital_stay(parent = self.GetParent())
-		evt.Skip()
-	#----------------------------------------------------------------
-	def _on_add_location_button_pressed(self, event):
-		gmOrganizationWidgets.manage_orgs(parent = self)	#self.GetParent())
-		event.Skip()
-	#----------------------------------------------------------------
-	def _on_ongoing_checkbox_checked(self, event):
-		if self._CHBOX_ongoing.IsChecked():
-			end = self._DPRW_end.GetData()
-			if end is None:
-				self._DPRW_end.display_as_valid(True)
-			else:
-				end = end.get_pydt()
-				now = gmDateTime.pydt_now_here()
-				if end > now:
-					self._DPRW_end.display_as_valid(True)
-				else:
-					self._DPRW_end.display_as_valid(False)
-		else:
-			self._DPRW_end.is_valid_timestamp()
-		event.Skip()
-
-#================================================================
-# hospitalizations related widgets/functions
-#----------------------------------------------------------------
-def manage_hospital_stays(parent=None):
-
-	pat = gmPerson.gmCurrentPatient()
-	emr = pat.get_emr()
-
-	if parent is None:
-		parent = wx.GetApp().GetTopWindow()
-	#-----------------------------------------
-	def get_tooltip(stay=None):
-		if stay is None:
-			return None
-		return stay.format (
-			include_procedures = True,
-			include_docs = True
-		)
-	#-----------------------------------------
-	def edit(stay=None):
-		return edit_hospital_stay(parent = parent, hospital_stay = stay)
-	#-----------------------------------------
-	def delete(stay=None):
-		if gmEMRStructItems.delete_hospital_stay(stay = stay['pk_hospital_stay']):
-			return True
-		gmDispatcher.send (
-			signal = u'statustext',
-			msg = _('Cannot delete hospitalization.'),
-			beep = True
-		)
-		return False
-	#-----------------------------------------
-	def refresh(lctrl):
-		stays = emr.get_hospital_stays()
-		items = [
-			[
-				s['admission'].strftime('%Y-%m-%d'),
-				gmTools.coalesce(s['discharge'], u'', function_initial = ('strftime', '%Y-%m-%d')),
-				s['episode'],
-				u'%s @ %s' % (s['ward'], s['hospital'])
-			] for s in stays
-		]
-		lctrl.set_string_items(items = items)
-		lctrl.set_data(data = stays)
-	#-----------------------------------------
-	gmListWidgets.get_choices_from_list (
-		parent = parent,
-		msg = _("The patient's hospitalizations:\n"),
-		caption = _('Editing hospitalizations ...'),
-		columns = [_('Admission'), _('Discharge'), _('Reason'), _('Hospital')],
-		single_selection = True,
-		edit_callback = edit,
-		new_callback = edit,
-		delete_callback = delete,
-		refresh_callback = refresh,
-		list_tooltip_callback = get_tooltip
-	)
-
-#----------------------------------------------------------------
-def edit_hospital_stay(parent=None, hospital_stay=None):
-	ea = cHospitalStayEditAreaPnl(parent = parent, id = -1)
-	ea.data = hospital_stay
-	ea.mode = gmTools.coalesce(hospital_stay, 'new', 'edit')
-	dlg = gmEditArea.cGenericEditAreaDlg2(parent = parent, id = -1, edit_area = ea, single_entry = True)
-	dlg.SetTitle(gmTools.coalesce(hospital_stay, _('Adding a hospitalization'), _('Editing a hospitalization')))
-	if dlg.ShowModal() == wx.ID_OK:
-		dlg.Destroy()
-		return True
-	dlg.Destroy()
-	return False
-
-#----------------------------------------------------------------
-class cHospitalWardPhraseWheel(gmPhraseWheel.cPhraseWheel):
-	"""Phrasewheel to allow selection of a hospitalization."""
-	def __init__(self, *args, **kwargs):
-
-		gmPhraseWheel.cPhraseWheel.__init__ (self, *args, **kwargs)
-
-		query = u"""
-		SELECT data, list_label, field_label FROM (
-			SELECT DISTINCT ON (data) * FROM ((
-
-				-- already-used org_units
-				SELECT
-					pk_org_unit
-						AS data,
-					ward || ' @ ' || hospital
-						AS list_label,
-					ward || ' @ ' || hospital
-						AS field_label,
-					1
-						AS rank
-				FROM
-					clin.v_hospital_stays
-				WHERE
-					ward %(fragment_condition)s
-						OR
-					hospital %(fragment_condition)s
-
-				) UNION ALL (
-				-- wards
-				SELECT
-					pk_org_unit
-						AS data,
-					unit || ' (' || l10n_unit_category || ') @ ' || organization
-						AS list_label,
-					unit || ' @ ' || organization
-						AS field_label,
-					2
-						AS rank
-				FROM
-					dem.v_org_units
-				WHERE
-					unit_category = 'Ward'
-						AND
-					unit %(fragment_condition)s
-						AND
-					NOT EXISTS (
-						SELECT 1 FROM clin.v_hospital_stays WHERE clin.v_hospital_stays.pk_org_unit = dem.v_org_units.pk_org_unit
-					)
-
-				) UNION ALL (
-				-- hospital units
-				SELECT
-					pk_org_unit
-						AS data,
-					unit || coalesce(' (' || l10n_unit_category || ')', '') || ' @ ' || organization || ' (' || l10n_organization_category || ')'
-						AS list_label,
-					unit || ' @ ' || organization
-						AS field_label,
-					3
-						AS rank
-				FROM
-					dem.v_org_units
-				WHERE
-					unit_category <> 'Ward'
-						AND
-					organization_category = 'Hospital'
-						AND
-					unit %(fragment_condition)s
-						AND
-					NOT EXISTS (
-						SELECT 1 FROM clin.v_hospital_stays WHERE clin.v_hospital_stays.pk_org_unit = dem.v_org_units.pk_org_unit
-					)
-
-				) UNION ALL (
-				-- any other units
-				SELECT
-					pk_org_unit
-						AS data,
-					unit || coalesce(' (' || l10n_unit_category || ')', '') || ' @ ' || organization || ' (' || l10n_organization_category || ')'
-						AS list_label,
-					unit || ' @ ' || organization
-						AS field_label,
-					3
-						AS rank
-				FROM
-					dem.v_org_units
-				WHERE
-					unit_category <> 'Ward'
-						AND
-					organization_category <> 'Hospital'
-						AND
-					unit %(fragment_condition)s
-						AND
-					NOT EXISTS (
-						SELECT 1 FROM clin.v_hospital_stays WHERE clin.v_hospital_stays.pk_org_unit = dem.v_org_units.pk_org_unit
-					)
-			)) AS all_matches
-			ORDER BY data, rank
-		) AS distinct_matches
-		ORDER BY rank, list_label
-		LIMIT 50
-		"""
-
-		mp = gmMatchProvider.cMatchProvider_SQL2(queries = [query])
-		mp.setThresholds(2, 4, 6)
-		self.matcher = mp
-		self.selection_only = True
-
-#----------------------------------------------------------------
-class cHospitalStayPhraseWheel(gmPhraseWheel.cPhraseWheel):
-	"""Phrasewheel to allow selection of a hospital-type org_unit."""
-	def __init__(self, *args, **kwargs):
-
-		gmPhraseWheel.cPhraseWheel.__init__ (self, *args, **kwargs)
-
-		ctxt = {'ctxt_pat': {'where_part': u'(pk_patient = %(pat)s) AND', 'placeholder': u'pat'}}
-
-		mp = gmMatchProvider.cMatchProvider_SQL2 (
-			queries = [
-u"""
-SELECT
-	pk_hospital_stay,
-	descr
-FROM (
-	SELECT DISTINCT ON (pk_hospital_stay)
-		pk_hospital_stay,
-		descr
-	FROM
-		(SELECT
-			pk_hospital_stay,
-			(
-				to_char(admission, 'YYYY-Mon-DD')
-				|| ' (' || ward || ' @ ' || hospital || '):'
-				|| episode
-				|| coalesce((' (' || health_issue || ')'), '')
-			) AS descr
-		 FROM
-		 	clin.v_hospital_stays
-		 WHERE
-			%(ctxt_pat)s (
-				hospital %(fragment_condition)s
-					OR
-				ward %(fragment_condition)s
-					OR
-				episode %(fragment_condition)s
-					OR
-				health_issue %(fragment_condition)s
-			)
-		) AS the_stays
-) AS distinct_stays
-ORDER BY descr
-LIMIT 25
-"""			],
-			context = ctxt
-		)
-		mp.setThresholds(3, 4, 6)
-		mp.set_context('pat', gmPerson.gmCurrentPatient().ID)
-
-		self.matcher = mp
-		self.selection_only = True
-
-#----------------------------------------------------------------
-from Gnumed.wxGladeWidgets import wxgHospitalStayEditAreaPnl
-
-class cHospitalStayEditAreaPnl(wxgHospitalStayEditAreaPnl.wxgHospitalStayEditAreaPnl, gmEditArea.cGenericEditAreaMixin):
-
-	def __init__(self, *args, **kwargs):
-		wxgHospitalStayEditAreaPnl.wxgHospitalStayEditAreaPnl.__init__(self, *args, **kwargs)
-		gmEditArea.cGenericEditAreaMixin.__init__(self)
-
-	#----------------------------------------------------------------
-	# generic Edit Area mixin API
-	#----------------------------------------------------------------
-	def _valid_for_save(self):
-
-		valid = True
-
-		if self._PRW_episode.GetValue().strip() == u'':
-			valid = False
-			self._PRW_episode.display_as_valid(False)
-			gmDispatcher.send(signal = 'statustext', msg = _('Must select an episode or enter a name for a new one. Cannot save hospitalization.'), beep = True)
-			self._PRW_episode.SetFocus()
-
-		if not self._PRW_admission.is_valid_timestamp(allow_empty = False):
-			valid = False
-			gmDispatcher.send(signal = 'statustext', msg = _('Missing admission data. Cannot save hospitalization.'), beep = True)
-			self._PRW_admission.SetFocus()
-
-		if self._PRW_discharge.is_valid_timestamp(allow_empty = True):
-			if self._PRW_discharge.date is not None:
-				adm = self._PRW_admission.date
-				discharge = self._PRW_discharge.date
-				# normalize for comparison
-				discharge = discharge.replace (
-					hour = adm.hour,
-					minute = adm.minute,
-					second = adm.second,
-					microsecond = adm.microsecond
-				)
-				if adm is not None:
-					if discharge == adm:
-						self._PRW_discharge.SetData(discharge + pydt.timedelta(seconds = 1))
-					elif not self._PRW_discharge.date > self._PRW_admission.date:
-						valid = False
-						self._PRW_discharge.display_as_valid(False)
-						gmDispatcher.send(signal = 'statustext', msg = _('Discharge date must be empty or later than admission. Cannot save hospitalization.'), beep = True)
-						self._PRW_discharge.SetFocus()
-
-		if self._PRW_hospital.GetData() is None:
-			valid = False
-			self._PRW_hospital.display_as_valid(False)
-			self.status_message = _('Must select a hospital. Cannot save hospitalization.')
-			self._PRW_hospital.SetFocus()
-		else:
-			self._PRW_hospital.display_as_valid(True)
-
-		return (valid is True)
-
-	#----------------------------------------------------------------
-	def _save_as_new(self):
-
-		pat = gmPerson.gmCurrentPatient()
-		emr = pat.get_emr()
-		stay = emr.add_hospital_stay(episode = self._PRW_episode.GetData(can_create = True), fk_org_unit = self._PRW_hospital.GetData())
-		stay['comment'] = self._TCTRL_comment.GetValue().strip()
-		stay['admission'] = self._PRW_admission.GetData()
-		stay['discharge'] = self._PRW_discharge.GetData()
-		stay['comment'] = self._TCTRL_comment.GetValue()
-		stay.save_payload()
-
-		self.data = stay
-		return True
-
-	#----------------------------------------------------------------
-	def _save_as_update(self):
-
-		self.data['pk_episode'] = self._PRW_episode.GetData(can_create = True)
-		self.data['pk_org_unit'] = self._PRW_hospital.GetData()
-		self.data['admission'] = self._PRW_admission.GetData()
-		self.data['discharge'] = self._PRW_discharge.GetData()
-		self.data['comment'] = self._TCTRL_comment.GetValue()
-		self.data.save_payload()
-
-		return True
-
-	#----------------------------------------------------------------
-	def _refresh_as_new(self):
-		self._PRW_hospital.SetText(value = u'', data = None)
-		self._PRW_episode.SetText(value = u'')
-		self._PRW_admission.SetText(data = gmDateTime.pydt_now_here())
-		self._PRW_discharge.SetText()
-		self._TCTRL_comment.SetValue(u'')
-		self._PRW_hospital.SetFocus()
-
-	#----------------------------------------------------------------
-	def _refresh_from_existing(self):
-		self._PRW_hospital.SetText(value = u'%s @ %s' % (self.data['ward'], self.data['hospital']), data = self.data['pk_org_unit'])
-
-		if self.data['pk_episode'] is not None:
-			self._PRW_episode.SetText(value = self.data['episode'], data = self.data['pk_episode'])
-
-		self._PRW_admission.SetText(data = self.data['admission'])
-		self._PRW_discharge.SetText(data = self.data['discharge'])
-		self._TCTRL_comment.SetValue(gmTools.coalesce(self.data['comment'], u''))
-
-		self._PRW_hospital.SetFocus()
-	#----------------------------------------------------------------
-	def _refresh_as_new_from_existing(self):
-		print "this was not expected to be used in this edit area"
-
 #================================================================
 # episode related widgets/functions
 #----------------------------------------------------------------
@@ -828,7 +87,7 @@ def edit_episode(parent=None, episode=None):
 def manage_episodes(parent=None):
 
 	pat = gmPerson.gmCurrentPatient()
-	emr = pat.get_emr()
+	emr = pat.emr
 
 	if parent is None:
 		parent = wx.GetApp().GetTopWindow()
@@ -871,7 +130,7 @@ def manage_episodes(parent=None):
 		items = [
 			[	e['description'],
 				gmTools.bool2subst(e['episode_open'], _(u'ongoing'), _(u'closed'), u'<unknown>'),
-				gmDateTime.pydt_strftime(e.best_guess_start_date, '%Y %b %d'),
+				gmDateTime.pydt_strftime(e.best_guess_clinical_start_date, '%Y %b %d'),
 				gmTools.coalesce(e['health_issue'], u'')
 			] for e in epis
 		]
@@ -1013,8 +272,16 @@ def move_episode_to_issue(episode=None, target_issue=None, save_to_backend=False
 		return True
 
 	# we got two open episodes at once, ask user
-	move_range = episode.get_access_range()
-	exist_range = existing_epi.get_access_range()
+	move_range = (episode.best_guess_clinical_start_date, episode.best_guess_clinical_end_date)
+	if move_range[1] is None:
+		move_range_end = u'?'
+	else:
+		move_range_end = move_range[1].strftime('%m/%y')
+	exist_range = (existing_epi.best_guess_clinical_start_date, existing_epi.best_guess_clinical_end_date)
+	if exist_range[1] is None:
+		exist_range_end = u'?'
+	else:
+		exist_range_end = exist_range[1].strftime('%m/%y')
 	question = _(
 		'You want to associate the running episode:\n\n'
 		' "%(new_epi_name)s" (%(new_epi_start)s - %(new_epi_end)s)\n\n'
@@ -1029,11 +296,11 @@ def move_episode_to_issue(episode=None, target_issue=None, save_to_backend=False
 	) % {
 		'new_epi_name': episode['description'],
 		'new_epi_start': move_range[0].strftime('%m/%y'),
-		'new_epi_end': move_range[1].strftime('%m/%y'),
+		'new_epi_end': move_range_end,
 		'issue_name': target_issue['description'],
 		'old_epi_name': existing_epi['description'],
 		'old_epi_start': exist_range[0].strftime('%m/%y'),
-		'old_epi_end': exist_range[1].strftime('%m/%y')
+		'old_epi_end': exist_range_end
 	}
 	dlg = gmGuiHelpers.c3ButtonQuestionDlg (
 		parent = None,
@@ -1255,7 +522,7 @@ limit 30"""
 		else:
 			pat = gmPerson.cPatient(aPK_obj = self.__patient_id)
 
-		emr = pat.get_emr()
+		emr = pat.emr
 		epi = emr.add_episode(episode_name = epi_name, is_open = self.__is_open_for_create_data)
 		if epi is None:
 			self.data = {}
@@ -1325,7 +592,7 @@ class cEpisodeEditAreaPnl(gmEditArea.cGenericEditAreaMixin, wxgEpisodeEditAreaPn
 	def _save_as_new(self):
 
 		pat = gmPerson.gmCurrentPatient()
-		emr = pat.get_emr()
+		emr = pat.emr
 
 		epi = emr.add_episode(episode_name = self._PRW_description.GetValue().strip())
 		epi['summary'] = self._TCTRL_status.GetValue().strip()
@@ -1648,7 +915,7 @@ class cIssueSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 		else:
 			pat = gmPerson.cPatient(aPK_obj = self.__patient_id)
 
-		emr = pat.get_emr()
+		emr = pat.emr
 		issue = emr.add_health_issue(issue_name = issue_name)
 
 		if issue is None:
@@ -1828,7 +1095,7 @@ limit 50""" % gmPerson.gmCurrentPatient().ID
 	#----------------------------------------------------------------
 	def _save_as_new(self):
 		pat = gmPerson.gmCurrentPatient()
-		emr = pat.get_emr()
+		emr = pat.emr
 
 		issue = emr.add_health_issue(issue_name = self._PRW_condition.GetValue().strip())
 
@@ -2120,7 +1387,7 @@ if __name__ == '__main__':
 	#----------------------------------------------------------------
 	def test_epsiode_edit_area_pnl():
 		app = wx.PyWidgetTester(size = (200, 300))
-		emr = pat.get_emr()
+		emr = pat.emr
 		epi = emr.get_episodes()[0]
 		pnl = cEpisodeEditAreaPnl(app.frame, -1, episode=epi)
 		app.frame.Show(True)
@@ -2128,33 +1395,28 @@ if __name__ == '__main__':
 	#----------------------------------------------------------------
 	def test_episode_edit_area_dialog():
 		app = wx.PyWidgetTester(size = (200, 300))
-		emr = pat.get_emr()
+		emr = pat.emr
 		epi = emr.get_episodes()[0]
 		edit_episode(parent=app.frame, episode=epi)
-	#----------------------------------------------------------------
-	def test_hospital_stay_prw():
-		app = wx.PyWidgetTester(size = (400, 40))
-		app.SetWidget(cHospitalStayPhraseWheel, id=-1, size=(180,20), pos=(10,20))
-		app.MainLoop()
+
 	#----------------------------------------------------------------
 	def test_episode_selection_prw():
 		app = wx.PyWidgetTester(size = (400, 40))
 		app.SetWidget(cEpisodeSelectionPhraseWheel, id=-1, size=(180,20), pos=(10,20))
 #		app.SetWidget(cEpisodeSelectionPhraseWheel, id=-1, size=(350,20), pos=(10,20), patient_id=pat.ID)
 		app.MainLoop()
+
 	#----------------------------------------------------------------
 	def test_health_issue_edit_area_dlg():
 		app = wx.PyWidgetTester(size = (200, 300))
 		edit_health_issue(parent=app.frame, issue=None)
+
 	#----------------------------------------------------------------
 	def test_health_issue_edit_area_pnl():
 		app = wx.PyWidgetTester(size = (200, 300))
 		app.SetWidget(cHealthIssueEditAreaPnl, id=-1, size = (400,400))
 		app.MainLoop()
-	#----------------------------------------------------------------
-	def test_edit_procedure():
-		app = wx.PyWidgetTester(size = (200, 300))
-		edit_procedure(parent=app.frame)
+
 	#================================================================
 
 	# obtain patient
@@ -2176,6 +1438,4 @@ if __name__ == '__main__':
 	#test_epsiode_edit_area_pnl()
 	#test_episode_edit_area_dialog()
 	#test_health_issue_edit_area_dlg()
-	#test_episode_selection_prw()
-	test_hospital_stay_prw()
-	#est_edit_procedure()
+	test_episode_selection_prw()
