@@ -44,6 +44,8 @@ from Gnumed.wxpython import gmDocumentWidgets
 from Gnumed.wxpython import gmGuiHelpers
 from Gnumed.wxpython import gmPregWidgets
 from Gnumed.wxpython import gmHabitWidgets
+from Gnumed.wxpython import gmHospitalStayWidgets
+from Gnumed.wxpython import gmProcedureWidgets
 
 
 _log = logging.getLogger('gm.patient')
@@ -58,10 +60,14 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 
 		self.__init_ui()
 		self.__register_interests()
+
 	#--------------------------------------------------------
 	# internal API
 	#--------------------------------------------------------
 	def __init_ui(self):
+
+		#self._LCTRL_history.debug = u'LCTRL_history_sizing'
+
 		# left
 		self._LCTRL_identity.set_columns(columns = [u''])
 		self._LCTRL_identity.item_tooltip_callback = self._calc_identity_item_tooltip
@@ -76,14 +82,14 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 		self._LCTRL_encounters.activate_callback = self._on_encounter_activated
 
 		# middle
-		self._LCTRL_problems.set_columns(columns = [u''])
-		self._LCTRL_problems.item_tooltip_callback = self._calc_problem_list_item_tooltip
-		self._LCTRL_problems.activate_callback = self._on_problem_activated
-
 		self._LCTRL_meds.set_columns(columns = [u''])
 		self._LCTRL_meds.item_tooltip_callback = self._calc_meds_list_item_tooltip
 		self._LCTRL_meds.activate_callback = self._on_meds_item_activated
 
+		self._LCTRL_problems.set_columns(columns = [u''])
+		self._LCTRL_problems.item_tooltip_callback = self._calc_problem_list_item_tooltip
+		self._LCTRL_problems.activate_callback = self._on_problem_activated
+
 		self._LCTRL_history.set_columns(columns = [u''])
 		self._LCTRL_history.item_tooltip_callback = self._calc_history_list_item_tooltip
 		self._LCTRL_history.activate_callback = self._on_history_item_activated
@@ -100,12 +106,12 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 		self._LCTRL_documents.set_columns(columns = [u''])
 		self._LCTRL_documents.item_tooltip_callback = self._calc_documents_list_item_tooltip
 		self._LCTRL_documents.activate_callback = self._on_document_activated
+
 	#--------------------------------------------------------
 	def __reset_ui_content(self):
 		self._LCTRL_identity.set_string_items()
 		self._LCTRL_contacts.set_string_items()
 		self._LCTRL_encounters.set_string_items()
-		self._PRW_encounter_range.SetText(value = u'', data = None)
 
 		self._LCTRL_problems.set_string_items()
 		self._LCTRL_meds.set_string_items()
@@ -114,6 +120,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 		self._LCTRL_inbox.set_string_items()
 		self._LCTRL_results.set_string_items()
 		self._LCTRL_documents.set_string_items()
+
 	#-----------------------------------------------------
 	# event handling
 	#-----------------------------------------------------
@@ -138,26 +145,22 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 #		self.__pat.register_before_switching_from_patient_callback(callback = self._before_switching_from_patient_callback)
 #		gmDispatcher.send(signal = u'register_pre_exit_callback', callback = self._pre_exit_callback)
 
-		self._PRW_encounter_range.add_callback_on_selection(callback = self._on_encounter_range_selected)
-	#--------------------------------------------------------
-	def _on_encounter_range_selected(self, data):
-		wx.CallAfter(self.__refresh_encounters, patient = gmPerson.gmCurrentPatient())
 	#--------------------------------------------------------
 	def _on_pre_patient_unselection(self):
 		# only empty out here, do NOT access the patient
 		# or else we will access the old patient while it
 		# may not be valid anymore ...
 		self.__reset_ui_content()
+
 	#--------------------------------------------------------
 	def _on_post_patient_selection(self):
 		self._schedule_data_reget()
+
 	#--------------------------------------------------------
 	def _on_database_signal(self, **kwds):
 
 		pat = gmPerson.gmCurrentPatient()
 		if not pat.connected:
-			# probably not needed:
-			#self._schedule_data_reget()
 			return True
 
 		if kwds['pk_identity'] != pat.ID:
@@ -178,17 +181,20 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			u'clin.vaccination',
 			u'clin.family_history',
 			u'clin.test_result',
+			u'clin.export_item',
+			u'clin.external_care',
 			u'dem.identity',
 			u'dem.names',
 			u'dem.lnk_identity2comm',
 			u'dem.lnk_job2person',
 			u'dem.message_inbox',
-			u'ref.auto_hint'		# no signal triggers in v21 just yet, however ...
+			u'ref.auto_hint'
 		]:
 			self._schedule_data_reget()
 			return True
 
 		return True
+
 	#-----------------------------------------------------
 	# reget-on-paint mixin API
 	#-----------------------------------------------------
@@ -219,7 +225,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 		list_items = []
 		list_data = []
 
-		emr = patient.get_emr()
+		emr = patient.emr
 		most_recent = emr.get_most_recent_results(no_of_results = 1)
 		if most_recent is None:
 			self._LCTRL_results.set_string_items(items = [])
@@ -289,10 +295,14 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 	def __refresh_inbox(self, patient=None):
 		list_items = []
 		list_data = []
+		highlight_list = []
+		line_idx = -1
 
 		overdue_messages = patient.overdue_messages
-		no_of_overdues = len(overdue_messages)
+		if len(overdue_messages) > 0:
+			highlight_list.extend(range(len(overdue_messages)))
 		for msg in overdue_messages:
+			line_idx += 1
 			list_items.append(_('overdue %s: %s') % (
 				gmDateTime.format_interval_medically(msg['interval_due']),
 				gmTools.coalesce(msg['comment'], u'?')
@@ -306,6 +316,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			# not relevant anymore ?
 			if msg['is_expired']:
 				continue
+			line_idx += 1
 			if msg['due_date'] is None:
 				label = u'%s%s' % (
 					msg['l10n_type'],
@@ -316,14 +327,16 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 					gmDateTime.format_interval_medically(msg['interval_due']),
 					gmTools.coalesce(msg['comment'], u'', u': %s')
 				)
-
 			list_items.append(label)
 			list_data.append(msg)
 
-		pk_enc = patient.get_emr(allow_user_interaction = False).active_encounter['pk_encounter']
+		pk_enc = patient.emr.active_encounter['pk_encounter']
 		for hint in patient._get_dynamic_hints(pk_encounter = pk_enc):
+			line_idx += 1
 			list_items.append(hint['title'])
 			list_data.append(hint)
+			if hint['highlight_as_priority']:
+				highlight_list.append(line_idx)
 
 		hints = patient.suppressed_hints
 		if len(hints) > 0:
@@ -333,14 +346,13 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 		self._LCTRL_inbox.set_string_items(items = list_items)
 		self._LCTRL_inbox.set_data(data = list_data)
 
-		if no_of_overdues > 0:
-			for idx in range(no_of_overdues):
-				self._LCTRL_inbox.SetItemTextColour(idx, wx.NamedColour('RED'))
+		for idx in highlight_list:
+			self._LCTRL_inbox.SetItemTextColour(idx, wx.NamedColour('RED'))
 
 	#-----------------------------------------------------
 	def _calc_inbox_item_tooltip(self, data):
 		if isinstance(data, gmProviderInbox.cInboxMessage):
-			return data.format(with_patient = False)
+			return data.format()
 
 		if isinstance(data, gmAutoHints.cDynamicHint):
 			return u'%s\n\n%s%s\n\n%s          %s' % (
@@ -355,6 +367,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			return data
 
 		return None
+
 	#-----------------------------------------------------
 	def _on_inbox_item_activated(self, event):
 
@@ -451,7 +464,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 				self._LCTRL_documents.SetItemTextColour(idx, wx.NamedColour('RED'))
 	#-----------------------------------------------------
 	def _calc_documents_list_item_tooltip(self, data):
-		emr = gmPerson.gmCurrentPatient().get_emr()
+		emr = gmPerson.gmCurrentPatient().emr
 
 		if isinstance(data, gmDocuments.cDocument):
 			return data.format()
@@ -477,12 +490,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 	#-----------------------------------------------------
 	def __refresh_encounters(self, patient=None):
 
-		cover_period = self._PRW_encounter_range.GetData()
-		if cover_period is None:
-			if self._PRW_encounter_range.GetValue().strip() != u'':
-				return
-
-		emr = patient.get_emr()
+		emr = patient.emr
 
 		list_items = []
 		list_data = []
@@ -534,18 +542,13 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			)
 			list_data.append(last)
 
-		if cover_period is not None:
-			item = _('Last %s:') % self._PRW_encounter_range.GetValue().strip()
-			list_items.append(item)
-			list_data.append(_('Statistics cover period'))
-
-		encs = emr.get_encounter_stats_by_type(cover_period = cover_period)
+		encs = emr.get_encounter_stats_by_type()
 		for enc in encs:
 			item = u' %s x %s' % (enc['frequency'], enc['l10n_type'])
 			list_items.append(item)
 			list_data.append(item)
 
-		stays = emr.get_hospital_stay_stats_by_hospital(cover_period = cover_period)
+		stays = emr.get_hospital_stay_stats_by_hospital()
 		for stay in stays:
 			item = u' %s x %s' % (
 				stay['frequency'],
@@ -561,7 +564,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 
 	#-----------------------------------------------------
 	def _calc_encounters_list_item_tooltip(self, data):
-		emr = gmPerson.gmCurrentPatient().get_emr()
+		emr = gmPerson.gmCurrentPatient().emr
 
 		if isinstance(data, gmEMRStructItems.cEncounter):
 			return data.format (
@@ -596,7 +599,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 				gmDispatcher.send(signal = 'display_widget', name = 'gmWaitingListPlugin')
 				return
 			if key == 'stay':
-				wx.CallAfter(gmEMRStructWidgets.manage_hospital_stays, parent = self)
+				wx.CallAfter(gmHospitalStayWidgets.manage_hospital_stays, parent = self)
 				return
 
 		wx.CallAfter(gmEncounterWidgets.manage_encounters, parent = self, ignore_OK_button = False)
@@ -604,7 +607,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 	#-----------------------------------------------------
 	#-----------------------------------------------------
 	def __refresh_history(self, patient=None):
-		emr = patient.get_emr()
+		emr = patient.emr
 
 		sort_key_list = []
 		date_format4sorting = '%Y %m %d %H %M %S'
@@ -784,6 +787,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			return data
 
 		return None
+
 	#-----------------------------------------------------
 	def _on_history_item_activated(self, event):
 		data = self._LCTRL_history.get_selected_item_data(only_one = True)
@@ -803,10 +807,10 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 				FamilyHistoryWidgets.edit_family_history(parent = self, family_history = data)
 				return
 			if isinstance(data, gmEMRStructItems.cHospitalStay):
-				gmEMRStructWidgets.edit_hospital_stay(parent = self, hospital_stay = data)
+				gmHospitalStayWidgets.edit_hospital_stay(parent = self, hospital_stay = data)
 				return
 			if isinstance(data, gmEMRStructItems.cPerformedProcedure):
-				gmEMRStructWidgets.edit_procedure(parent = self, procedure = data)
+				gmProcedureWidgets.edit_procedure(parent = self, procedure = data)
 				return
 			if isinstance(data, gmVaccination.cVaccination):
 				gmVaccWidgets.edit_vaccination(parent = self, vaccination = data, single_entry = True)
@@ -820,10 +824,10 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			FamilyHistoryWidgets.manage_family_history(parent = self)
 			return
 		if isinstance(data, gmEMRStructItems.cHospitalStay):
-			gmEMRStructWidgets.manage_hospital_stays(parent = self)
+			gmHospitalStayWidgets.manage_hospital_stays(parent = self)
 			return
 		if isinstance(data, gmEMRStructItems.cPerformedProcedure):
-			gmEMRStructWidgets.manage_performed_procedures(parent = self)
+			gmProcedureWidgets.manage_performed_procedures(parent = self)
 			return
 		if isinstance(data, gmVaccination.cVaccination):
 			gmVaccWidgets.manage_vaccinations(parent = self)
@@ -834,7 +838,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 	#-----------------------------------------------------
 	def __refresh_meds(self, patient=None):
 
-		emr = patient.get_emr()
+		emr = patient.emr
 
 		list_items = []
 		data_items = []
@@ -846,35 +850,27 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			list_items.append(_('active substance abuse'))
 			data_items.append(u'\n'.join([ a.format(left_margin=0, date_format='%Y %b %d', single_line=True) for a in abuses ]))
 
-		# list by brand or substance:
+		# list by product or substance:
 		intakes = emr.get_current_medications(include_inactive = False, include_unapproved = True, order_by = u'substance')
-		multi_brands_already_seen = []
+		multi_products_already_seen = []
 		for intake in intakes:
-			brand = intake.containing_drug
-			if brand is None or len(brand['pk_components']) == 1:
-				list_items.append(_('%s %s %s%s') % (
+			drug = intake.containing_drug
+			if len(drug['components']) == 1:
+				list_items.append(_('%s %s%s%s') % (
 					intake['substance'],
 					intake['amount'],
-					intake['unit'],
-					gmTools.coalesce (
-						intake['schedule'],
-						u'',
-						u': %s'
-					)
+					intake.formatted_units,
+					gmTools.coalesce(intake['schedule'], u'', u': %s')
 				))
 				data_items.append(intake)
 			else:
-				if intake['brand'] in multi_brands_already_seen:
+				if intake['product'] in multi_products_already_seen:
 					continue
-				multi_brands_already_seen.append(intake['brand'])
+				multi_products_already_seen.append(intake['product'])
 				list_items.append(_('%s %s%s') % (
-					intake['brand'],
-					brand['preparation'],
-					gmTools.coalesce (
-						intake['schedule'],
-						u'',
-						u': %s'
-					)
+					intake['product'],
+					drug['l10n_preparation'],
+					gmTools.coalesce(intake['schedule'], u'', u': %s')
 				))
 				data_items.append(intake)
 
@@ -888,17 +884,18 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 	def _calc_meds_list_item_tooltip(self, data):
 		if isinstance(data, basestring):
 			return data
-		emr = gmPerson.gmCurrentPatient().get_emr()
+		emr = gmPerson.gmCurrentPatient().emr
 		atcs = []
 		if data['atc_substance'] is not None:
 			atcs.append(data['atc_substance'])
-#		if data['atc_brand'] is not None:
-#			atcs.append(data['atc_brand'])
-#		allg = emr.is_allergic_to(atcs = tuple(atcs), inns = (data['substance'],), brand = data['brand'])
+#		if data['atc_drug'] is not None:
+#			atcs.append(data['atc_drug'])
+#		allg = emr.is_allergic_to(atcs = tuple(atcs), inns = (data['substance'],), drug = data['product'])
 		allg = emr.is_allergic_to(atcs = tuple(atcs), inns = (data['substance'],))
 		if allg is False:
 			allg = None
-		return data.format(single_line = False, allergy = allg, show_all_brand_components = True)
+		return data.format(single_line = False, allergy = allg, show_all_product_components = True)
+
 	#-----------------------------------------------------
 	def _on_meds_item_activated(self, event):
 		data = self._LCTRL_meds.get_selected_item_data(only_one = True)
@@ -916,10 +913,11 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			return
 
 		gmDispatcher.send(signal = 'display_widget', name = 'gmCurrentSubstancesPlugin')
+
 	#-----------------------------------------------------
 	#-----------------------------------------------------
 	def __refresh_contacts(self, patient=None):
-		emr = patient.get_emr()
+		emr = patient.emr
 
 		list_items = []
 		list_data = []
@@ -956,7 +954,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 
 		provider = patient.primary_provider
 		if provider is not None:
-			list_items.append(_('in-praxis: %s') % patient.primary_provider_identity['description_gender'])
+			list_items.append(_('in-praxis: %s') % patient.primary_provider_identity.get_description_gender(with_nickname = False))
 			list_data.append(provider)
 
 		for item in emr.external_care_items:
@@ -971,6 +969,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 		self._LCTRL_contacts.set_data(data = list_data)
 		if is_in_hospital:
 			self._LCTRL_contacts.SetItemTextColour(0, wx.NamedColour('RED'))
+
 	#-----------------------------------------------------
 	def _calc_contacts_list_item_tooltip(self, data):
 
@@ -1028,6 +1027,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			)
 
 		return None
+
 	#-----------------------------------------------------
 	def _on_contacts_item_activated(self, event):
 		data = self._LCTRL_contacts.get_selected_item_data(only_one = True)
@@ -1035,7 +1035,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			# <ctrl> down ?
 			if wx.GetKeyState(wx.WXK_CONTROL):
 				if isinstance(data, gmEMRStructItems.cHospitalStay):
-					gmEMRStructWidgets.edit_hospital_stay(parent = self, hospital_stay = data)
+					gmHospitalStayWidgets.edit_hospital_stay(parent = self, hospital_stay = data)
 					return
 				if isinstance(data, gmDemographicRecord.cPatientAddress):
 					pass
@@ -1048,10 +1048,11 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 					pass
 
 		gmDispatcher.send(signal = 'display_widget', name = 'gmNotebookedPatientEditionPlugin')
+
 	#-----------------------------------------------------
 	#-----------------------------------------------------
 	def __refresh_problems(self, patient=None):
-		emr = patient.get_emr()
+		emr = patient.emr
 
 		problems = [
 			p for p in emr.get_problems(include_closed_episodes = False, include_irrelevant_issues = False)
@@ -1079,8 +1080,9 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 				list_items.append(u'%s: %s' % (problem['problem'], last))
 			list_data.append(problem)
 
-		care = emr.get_external_care_items()
+		care = emr.get_external_care_items(exclude_inactive = True)
 		for item in care:
+			# skip those already-shown(-or-not)
 			if item['pk_health_issue'] is not None:
 				continue
 			list_items.append(_('extrnl: %s (%s@%s)') % (
@@ -1092,6 +1094,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 
 		self._LCTRL_problems.set_string_items(items = list_items)
 		self._LCTRL_problems.set_data(data = list_data)
+
 	#-----------------------------------------------------
 	def _calc_problem_list_item_tooltip(self, data):
 
@@ -1102,7 +1105,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 				with_comms = True
 			))
 
-		emr = gmPerson.gmCurrentPatient().get_emr()
+		emr = gmPerson.gmCurrentPatient().emr
 
 		if data['type'] == 'issue':
 			issue = emr.problem2issue(data)
@@ -1134,13 +1137,14 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			return tt
 
 		return None
+
 	#-----------------------------------------------------
 	def _on_problem_activated(self, event):
 		data = self._LCTRL_problems.get_selected_item_data(only_one = True)
 		if data is not None:
 			# <ctrl> down ?
 			if wx.GetKeyState(wx.WXK_CONTROL):
-				emr = gmPerson.gmCurrentPatient().get_emr()
+				emr = gmPerson.gmCurrentPatient().emr
 				if data['type'] == 'issue':
 					gmEMRStructWidgets.edit_health_issue(parent = self, issue = emr.problem2issue(data))
 					return
@@ -1149,6 +1153,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 					return
 
 		gmDispatcher.send(signal = 'display_widget', name = 'gmEMRBrowserPlugin')
+
 	#-----------------------------------------------------
 	#-----------------------------------------------------
 	def __refresh_identity(self, patient=None):
@@ -1180,6 +1185,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 
 		self._LCTRL_identity.set_string_items(items = items)
 		self._LCTRL_identity.set_data(data = data)
+
 	#-----------------------------------------------------
 	def _calc_identity_item_tooltip(self, data):
 		if isinstance(data, gmPerson.cPersonName):
@@ -1199,6 +1205,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 				return tt + (u'\n\n' + _('Activities:\n\n%s') % val['activities'])
 
 		return None
+
 	#-----------------------------------------------------
 	def _on_identity_item_activated(self, event):
 		data = self._LCTRL_identity.get_selected_item_data(only_one = True)
@@ -1230,6 +1237,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			if key == 'job':
 				gmDemographicsWidgets.edit_occupation()
 				return
+
 #============================================================
 # main
 #------------------------------------------------------------
