@@ -209,6 +209,7 @@ class cPhraseWheelBase(wx.TextCtrl):
 				self._create_data()
 
 		return self._data
+
 	#---------------------------------------------------------
 	def SetText(self, value=u'', data=None, suppress_smarts=False):
 
@@ -386,9 +387,9 @@ class cPhraseWheelBase(wx.TextCtrl):
 	#--------------------------------------------------------
 	def _set_speller_word_separators(self, word_separators):
 		if word_separators is None:
-			self.__speller_word_separators = regex.compile(default_spelling_word_separators, flags = regex.LOCALE | regex.UNICODE)
+			self.__speller_word_separators = regex.compile(default_spelling_word_separators, flags = regex.UNICODE)
 		else:
-			self.__speller_word_separators = regex.compile(word_separators, flags = regex.LOCALE | regex.UNICODE)
+			self.__speller_word_separators = regex.compile(word_separators, flags = regex.UNICODE)
 
 	def _get_speller_word_separators(self):
 		return self.__speller_word_separators.pattern
@@ -593,6 +594,7 @@ class cPhraseWheelBase(wx.TextCtrl):
 						for suggestion in suggestions
 				]
 				self._picklist.SetItems(self._current_match_candidates)
+
 	#--------------------------------------------------------
 	# tooltip handling
 	#--------------------------------------------------------
@@ -601,6 +603,7 @@ class cPhraseWheelBase(wx.TextCtrl):
 		# per data item dynamic tooltips,
 		# by default do not support dynamic tooltip parts:
 		return None
+
 	#--------------------------------------------------------
 	def __recalculate_tooltip(self):
 		"""Calculate dynamic tooltip part based on data item.
@@ -749,7 +752,7 @@ class cPhraseWheelBase(wx.TextCtrl):
 
 		# check value against final_regex if any given
 		if self.__final_regex.match(self.GetValue().strip()) is None:
-			gmDispatcher.send(signal = 'statustext', msg = self.final_regex_error_msg)
+			gmDispatcher.send(signal = 'statustext', msg = self.final_regex_error_msg % self.final_regex)
 			is_valid = False
 
 		self.display_as_valid(valid = is_valid)
@@ -919,12 +922,14 @@ class cPhraseWheelBase(wx.TextCtrl):
 	def __mac_log(self, msg):
 		if self.__use_fake_popup:
 			_log.debug(msg)
+
 	#--------------------------------------------------------
 	def __char_is_allowed(self, char=None):
 		# if undefined accept all chars
 		if self.accepted_chars is None:
 			return True
 		return (self.__accepted_chars.match(char) is not None)
+
 	#--------------------------------------------------------
 	def _set_accepted_chars(self, accepted_chars=None):
 		if accepted_chars is None:
@@ -938,22 +943,25 @@ class cPhraseWheelBase(wx.TextCtrl):
 		return self.__accepted_chars.pattern
 
 	accepted_chars = property(_get_accepted_chars, _set_accepted_chars)
+
 	#--------------------------------------------------------
-	def _set_final_regex(self, final_regex='.*'):
-		self.__final_regex = regex.compile(final_regex, flags = regex.LOCALE | regex.UNICODE)
+	def _set_final_regex(self, final_regex=r'.*'):
+		self.__final_regex = regex.compile(final_regex, flags = regex.UNICODE)
 
 	def _get_final_regex(self):
 		return self.__final_regex.pattern
 
 	final_regex = property(_get_final_regex, _set_final_regex)
+
 	#--------------------------------------------------------
 	def _set_final_regex_error_msg(self, msg):
-		self.__final_regex_error_msg = msg % self.final_regex
+		self.__final_regex_error_msg = msg
 
 	def _get_final_regex_error_msg(self):
 		return self.__final_regex_error_msg
 
 	final_regex_error_msg = property(_get_final_regex_error_msg, _set_final_regex_error_msg)
+
 	#--------------------------------------------------------
 	# data munging
 	#--------------------------------------------------------
@@ -1045,7 +1053,7 @@ class cPhraseWheelBase(wx.TextCtrl):
 #seaching ones own previous text entered  would usually be instring but
 #weighted (ie the phrases you use the most auto filter to the top)
 
-#Searching a drug database for a   drug brand name is usually more
+#Searching a drug database for a   drug product name is usually more
 #functional if it does a start string search, not an instring search which is
 #much slower and usually unecesary.  There are many other examples but trust
 #me one needs both
@@ -1068,6 +1076,7 @@ class cPhraseWheel(cPhraseWheelBase):
 			return None
 
 		return self._data.values()[0]['data']
+
 	#---------------------------------------------------------
 	def SetData(self, data=None):
 		"""Set the data and thereby set the value, too. if possible.
@@ -1109,6 +1118,7 @@ class cPhraseWheel(cPhraseWheelBase):
 		self.data = self._dictify_data(data = data)
 		self.display_as_valid(valid = True)
 		return True
+
 	#--------------------------------------------------------
 	# internal API
 	#--------------------------------------------------------
@@ -1122,6 +1132,7 @@ class cPhraseWheel(cPhraseWheelBase):
 			return
 
 		return super(cPhraseWheel, self)._show_picklist(input2match = input2match)
+
 	#--------------------------------------------------------
 	def _set_data_to_first_match(self):
 		# data already set ?
@@ -1137,7 +1148,7 @@ class cPhraseWheel(cPhraseWheelBase):
 		self._update_candidates_in_picklist(val = val)
 		for candidate in self._current_match_candidates:
 			if candidate['field_label'] == val:
-				self.data = {candidate['field_label']: candidate}
+				self._update_data_from_picked_item(candidate)
 				self.MarkDirty()
 				# tell listeners about the user's selection
 				for callback in self._on_selection_callbacks:
@@ -1151,12 +1162,15 @@ class cPhraseWheel(cPhraseWheelBase):
 			return False
 
 		return True
+
 	#---------------------------------------------------------
 	def _adjust_data_after_text_update(self):
 		self.data = {}
+
 	#---------------------------------------------------------
 	def _extract_fragment_to_match_on(self):
 		return self.GetValue().strip()
+
 	#---------------------------------------------------------
 	def _dictify_data(self, data=None, value=None):
 		# assume data to always be old style
@@ -1312,7 +1326,7 @@ class cMultiPhraseWheel(cPhraseWheelBase):
 		after selection from picklist phrase_separators[0] is
 		added to the end of the match in the PRW
 		"""
-		self.__phrase_separators = regex.compile(phrase_separators, flags = regex.LOCALE | regex.UNICODE)
+		self.__phrase_separators = regex.compile(phrase_separators, flags = regex.UNICODE)
 
 	def _get_phrase_separators(self):
 		return self.__phrase_separators.pattern
