@@ -244,6 +244,39 @@ else
 	echo "found"
 fi
 
+echo -n " 'pdfinfo' command... "
+BIN=`which pdfinfo`
+if [ "x${BIN}x" == "xx" ]; then
+	echo ""
+	echo "  INFO : You don't seem to have the 'pdfinfo' command installed."
+	echo "  INFO : It can be used by GNUmed to extract metadata from"
+	echo "  INFO : files for display within GNUmed."
+else
+	echo "found"
+fi
+
+echo -n " 'pdfdetach' command... "
+BIN=`which pdfdetach`
+if [ "x${BIN}x" == "xx" ]; then
+	echo ""
+	echo "  INFO : You don't seem to have the 'pdfdetach' command installed."
+	echo "  INFO : It can be used by GNUmed to extract metadata from"
+	echo "  INFO : files for display within GNUmed."
+else
+	echo "found"
+fi
+
+echo -n " 'pdfsig' command... "
+BIN=`which pdfsig`
+if [ "x${BIN}x" == "xx" ]; then
+	echo ""
+	echo "  INFO : You don't seem to have the 'pdfsig' command installed."
+	echo "  INFO : It can be used by GNUmed to extract metadata from"
+	echo "  INFO : files for display within GNUmed."
+else
+	echo "found"
+fi
+
 echo -n " 'dmtxwrite' command... "
 BIN=`which dmtxwrite`
 if [ "x${BIN}x" == "xx" ]; then
@@ -346,6 +379,37 @@ else
 	echo "found"
 fi
 
+echo -n " 'qpdf' command... "
+BIN=`which qpdf`
+if [ "x${BIN}x" == "xx" ]; then
+	echo ""
+	echo "  INFO : You don't seem to have a 'qpdf' command installed."
+	echo "  INFO : It is used to encrypt PDF files generated by GNUmed."
+else
+	echo "found"
+fi
+
+echo -n " 'lacheck' command... "
+BIN=`which lacheck`
+if [ "x${BIN}x" == "xx" ]; then
+	echo ""
+	echo "  INFO : You don't seem to have a 'lacheck' command installed."
+	echo "  INFO : It is used to check LateX files used by GNUmed."
+else
+	echo "found"
+fi
+
+echo -n " 'chktex' command... "
+BIN=`which chktex`
+if [ "x${BIN}x" == "xx" ]; then
+	echo ""
+	echo "  INFO : You don't seem to have a 'chktex' command installed."
+	echo "  INFO : It is used to check LateX files used by GNUmed."
+else
+	echo "found"
+fi
+
+#-----------------------------------------------------------------
 
 echo ""
 read -p "Press <RETURN> key to continue."
